@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/go-errors/errors"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 )
 
@@ -22,6 +23,17 @@ func (self *CommitCommands) RewordLastCommit(message string) error {
 	return self.cmd.New("git commit --allow-empty --amend --only -m " + self.cmd.Quote(message)).Run()
 }
 
+// ResetAuthor resets the author of the topmost commit
+func (self *CommitCommands) ResetAuthor() error {
+	return self.cmd.New("git commit --allow-empty --only --no-edit --amend --reset-author").Run()
+}
+
+// Sets the commit's author to the supplied value. Value is expected to be of the form 'Name <Email>'
+func (self *CommitCommands) SetAuthor(value string) error {
+	commandStr := fmt.Sprintf("git commit --allow-empty --only --no-edit --amend --author=%s", self.cmd.Quote(value))
+	return self.cmd.New(commandStr).Run()
+}
+
 // ResetToCommit reset to commit
 func (self *CommitCommands) ResetToCommit(sha string, strength string, envVars []string) error {
 	return self.cmd.New(fmt.Sprintf("git reset --%s %s", strength, sha)).
@@ -70,10 +82,37 @@ func (self *CommitCommands) GetHeadCommitMessage() (string, error) {
 func (self *CommitCommands) GetCommitMessage(commitSha string) (string, error) {
 	cmdStr := "git rev-list --format=%B --max-count=1 " + commitSha
 	messageWithHeader, err := self.cmd.New(cmdStr).DontLog().RunWithOutput()
-	message := strings.Join(strings.SplitAfter(messageWithHeader, "\n")[1:], "\n")
+	message := strings.Join(strings.SplitAfter(messageWithHeader, "\n")[1:], "")
 	return strings.TrimSpace(message), err
 }
 
+func (self *CommitCommands) GetCommitDiff(commitSha string) (string, error) {
+	cmdStr := "git show --no-color " + commitSha
+	diff, err := self.cmd.New(cmdStr).DontLog().RunWithOutput()
+	return diff, err
+}
+
+type Author struct {
+	Name  string
+	Email string
+}
+
+func (self *CommitCommands) GetCommitAuthor(commitSha string) (Author, error) {
+	cmdStr := "git show --no-patch --pretty=format:'%an%x00%ae' " + commitSha
+	output, err := self.cmd.New(cmdStr).DontLog().RunWithOutput()
+	if err != nil {
+		return Author{}, err
+	}
+
+	split := strings.SplitN(strings.TrimSpace(output), "\x00", 2)
+	if len(split) < 2 {
+		return Author{}, errors.New("unexpected git output")
+	}
+
+	author := Author{Name: split[0], Email: split[1]}
+	return author, err
+}
+
 func (self *CommitCommands) GetCommitMessageFirstLine(sha string) (string, error) {
 	return self.GetCommitMessagesFirstLine([]string{sha})
 }
