@@ -1,6 +1,8 @@
 package git_commands
 
 import (
+	"sync"
+
 	gogit "github.com/jesseduffield/go-git/v5"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 	"github.com/jesseduffield/lazygit/pkg/common"
@@ -13,6 +15,8 @@ type GitCommon struct {
 	dotGitDir string
 	repo      *gogit.Repository
 	config    *ConfigCommands
+	// mutex for doing things like push/pull/fetch
+	syncMutex *sync.Mutex
 }
 
 func NewGitCommon(
@@ -22,6 +26,7 @@ func NewGitCommon(
 	dotGitDir string,
 	repo *gogit.Repository,
 	config *ConfigCommands,
+	syncMutex *sync.Mutex,
 ) *GitCommon {
 	return &GitCommon{
 		Common:    cmn,
@@ -30,5 +35,6 @@ func NewGitCommon(
 		dotGitDir: dotGitDir,
 		repo:      repo,
 		config:    config,
+		syncMutex: syncMutex,
 	}
 }
