@@ -5,7 +5,6 @@ import (
 	"strconv"
 
 	"github.com/go-errors/errors"
-	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
@@ -59,14 +58,16 @@ func (self *FileCommands) GetEditCmdStr(filename string, lineNumber int) (string
 	}
 
 	editCmdTemplate := self.UserConfig.OS.EditCommandTemplate
-	if editCmdTemplate == config.DefaultEditCommandTemplate {
+	if len(editCmdTemplate) == 0 {
 		switch editor {
-		case "emacs", "nano", "vi", "vim":
-			editCmdTemplate = "{{editor}} +{{line}} {{filename}}"
+		case "emacs", "nano", "vi", "vim", "nvim":
+			editCmdTemplate = "{{editor}} +{{line}} -- {{filename}}"
 		case "subl":
-			editCmdTemplate = "{{editor}} {{filename}}:{{line}}"
+			editCmdTemplate = "{{editor}} -- {{filename}}:{{line}}"
 		case "code":
-			editCmdTemplate = "{{editor}} -r --goto {{filename}}:{{line}}"
+			editCmdTemplate = "{{editor}} -r --goto -- {{filename}}:{{line}}"
+		default:
+			editCmdTemplate = "{{editor}} -- {{filename}}"
 		}
 	}
 	return utils.ResolvePlaceholderString(editCmdTemplate, templateValues), nil
