@@ -47,7 +47,7 @@ func (self *SyncCommands) PushCmdObj(opts PushOpts) (oscommands.ICmdObj, error)
 		cmdStr += " " + self.cmd.Quote(opts.UpstreamBranch)
 	}
 
-	cmdObj := self.cmd.New(cmdStr).PromptOnCredentialRequest()
+	cmdObj := self.cmd.New(cmdStr).PromptOnCredentialRequest().WithMutex(self.syncMutex)
 	return cmdObj, nil
 }
 
@@ -83,7 +83,7 @@ func (self *SyncCommands) Fetch(opts FetchOptions) error {
 	} else {
 		cmdObj.PromptOnCredentialRequest()
 	}
-	return cmdObj.Run()
+	return cmdObj.WithMutex(self.syncMutex).Run()
 }
 
 type PullOptions struct {
@@ -108,15 +108,15 @@ func (self *SyncCommands) Pull(opts PullOptions) error {
 
 	// setting GIT_SEQUENCE_EDITOR to ':' as a way of skipping it, in case the user
 	// has 'pull.rebase = interactive' configured.
-	return self.cmd.New(cmdStr).AddEnvVars("GIT_SEQUENCE_EDITOR=:").PromptOnCredentialRequest().Run()
+	return self.cmd.New(cmdStr).AddEnvVars("GIT_SEQUENCE_EDITOR=:").PromptOnCredentialRequest().WithMutex(self.syncMutex).Run()
 }
 
 func (self *SyncCommands) FastForward(branchName string, remoteName string, remoteBranchName string) error {
 	cmdStr := fmt.Sprintf("git fetch %s %s:%s", self.cmd.Quote(remoteName), self.cmd.Quote(remoteBranchName), self.cmd.Quote(branchName))
-	return self.cmd.New(cmdStr).PromptOnCredentialRequest().Run()
+	return self.cmd.New(cmdStr).PromptOnCredentialRequest().WithMutex(self.syncMutex).Run()
 }
 
 func (self *SyncCommands) FetchRemote(remoteName string) error {
 	cmdStr := fmt.Sprintf("git fetch %s", self.cmd.Quote(remoteName))
-	return self.cmd.New(cmdStr).PromptOnCredentialRequest().Run()
+	return self.cmd.New(cmdStr).PromptOnCredentialRequest().WithMutex(self.syncMutex).Run()
 }
