@@ -2,6 +2,7 @@ package loaders
 
 import (
 	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
@@ -11,32 +12,14 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-func NewDummyCommitLoader() *CommitLoader {
-	cmn := utils.NewDummyCommon()
-
-	return &CommitLoader{
-		Common:               cmn,
-		cmd:                  nil,
-		getCurrentBranchName: func() (string, string, error) { return "master", "master", nil },
-		getRebaseMode:        func() (enums.RebaseMode, error) { return enums.REBASE_MODE_NONE, nil },
-		dotGitDir:            ".git",
-		readFile: func(filename string) ([]byte, error) {
-			return []byte(""), nil
-		},
-		walkFiles: func(root string, fn filepath.WalkFunc) error {
-			return nil
-		},
-	}
-}
-
-const commitsOutput = `0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield| (HEAD -> better-tests)|b21997d6b4cbdf84b149|better typing for rebase mode
-b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164|1640824515|Jesse Duffield| (origin/better-tests)|e94e8fc5b6fab4cb755f|fix logging
-e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c|1640823749|Jesse Duffield||d8084cd558925eb7c9c3|refactor
-d8084cd558925eb7c9c38afeed5725c21653ab90|1640821426|Jesse Duffield||65f910ebd85283b5cce9|WIP
-65f910ebd85283b5cce9bf67d03d3f1a9ea3813a|1640821275|Jesse Duffield||26c07b1ab33860a1a759|WIP
-26c07b1ab33860a1a7591a0638f9925ccf497ffa|1640750752|Jesse Duffield||3d4470a6c072208722e5|WIP
-3d4470a6c072208722e5ae9a54bcb9634959a1c5|1640748818|Jesse Duffield||053a66a7be3da43aacdc|WIP
-053a66a7be3da43aacdc7aa78e1fe757b82c4dd2|1640739815|Jesse Duffield||985fe482e806b172aea4|refactoring the config struct`
+var commitsOutput = strings.Replace(`0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield|jessedduffield@gmail.com| (HEAD -> better-tests)|b21997d6b4cbdf84b149|better typing for rebase mode
+b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164|1640824515|Jesse Duffield|jessedduffield@gmail.com| (origin/better-tests)|e94e8fc5b6fab4cb755f|fix logging
+e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c|1640823749|Jesse Duffield|jessedduffield@gmail.com||d8084cd558925eb7c9c3|refactor
+d8084cd558925eb7c9c38afeed5725c21653ab90|1640821426|Jesse Duffield|jessedduffield@gmail.com||65f910ebd85283b5cce9|WIP
+65f910ebd85283b5cce9bf67d03d3f1a9ea3813a|1640821275|Jesse Duffield|jessedduffield@gmail.com||26c07b1ab33860a1a759|WIP
+26c07b1ab33860a1a7591a0638f9925ccf497ffa|1640750752|Jesse Duffield|jessedduffield@gmail.com||3d4470a6c072208722e5|WIP
+3d4470a6c072208722e5ae9a54bcb9634959a1c5|1640748818|Jesse Duffield|jessedduffield@gmail.com||053a66a7be3da43aacdc|WIP
+053a66a7be3da43aacdc7aa78e1fe757b82c4dd2|1640739815|Jesse Duffield|jessedduffield@gmail.com||985fe482e806b172aea4|refactoring the config struct`, "|", "\x00", -1)
 
 func TestGetCommits(t *testing.T) {
 	type scenario struct {
@@ -57,7 +40,7 @@ func TestGetCommits(t *testing.T) {
 			opts:              GetCommitsOptions{RefName: "HEAD", IncludeRebaseCommits: false},
 			runner: oscommands.NewFakeRunner(t).
 				Expect(`git merge-base "HEAD" "HEAD"@{u}`, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
-				Expect(`git log "HEAD" --topo-order  --oneline --pretty=format:"%H|%at|%aN|%d|%p|%s" --abbrev=20`, "", nil),
+				Expect(`git -c log.showSignature=false log "HEAD" --topo-order  --oneline --pretty=format:"%H%x00%at%x00%aN%x00%ae%x00%d%x00%p%x00%s" --abbrev=40`, "", nil),
 
 			expectedCommits: []*models.Commit{},
 			expectedError:   nil,
@@ -71,7 +54,7 @@ func TestGetCommits(t *testing.T) {
 				// here it's seeing which commits are yet to be pushed
 				Expect(`git merge-base "HEAD" "HEAD"@{u}`, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
 				// here it's actually getting all the commits in a formatted form, one per line
-				Expect(`git log "HEAD" --topo-order  --oneline --pretty=format:"%H|%at|%aN|%d|%p|%s" --abbrev=20`, commitsOutput, nil).
+				Expect(`git -c log.showSignature=false log "HEAD" --topo-order  --oneline --pretty=format:"%H%x00%at%x00%aN%x00%ae%x00%d%x00%p%x00%s" --abbrev=40`, commitsOutput, nil).
 				// here it's seeing where our branch diverged from the master branch so that we can mark that commit and parent commits as 'merged'
 				Expect(`git merge-base "HEAD" "master"`, "26c07b1ab33860a1a7591a0638f9925ccf497ffa", nil),
 
@@ -83,7 +66,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "(HEAD -> better-tests)",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640826609,
 					Parents: []string{
 						"b21997d6b4cbdf84b149",
@@ -96,7 +80,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "(origin/better-tests)",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640824515,
 					Parents: []string{
 						"e94e8fc5b6fab4cb755f",
@@ -109,7 +94,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640823749,
 					Parents: []string{
 						"d8084cd558925eb7c9c3",
@@ -122,7 +108,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640821426,
 					Parents: []string{
 						"65f910ebd85283b5cce9",
@@ -135,7 +122,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640821275,
 					Parents: []string{
 						"26c07b1ab33860a1a759",
@@ -148,7 +136,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640750752,
 					Parents: []string{
 						"3d4470a6c072208722e5",
@@ -161,7 +150,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640748818,
 					Parents: []string{
 						"053a66a7be3da43aacdc",
@@ -174,7 +164,8 @@ func TestGetCommits(t *testing.T) {
 					Action:        "",
 					Tags:          []string{},
 					ExtraInfo:     "",
-					Author:        "Jesse Duffield",
+					AuthorName:    "Jesse Duffield",
+					AuthorEmail:   "jessedduffield@gmail.com",
 					UnixTimestamp: 1640739815,
 					Parents: []string{
 						"985fe482e806b172aea4",
