@@ -1,6 +1,7 @@
 package config
 
 import (
+	"fmt"
 	"io/ioutil"
 	"os"
 	"path/filepath"
@@ -43,13 +44,22 @@ type AppConfigurer interface {
 	GetUserConfigPaths() []string
 	GetUserConfigDir() string
 	ReloadUserConfig() error
+	GetTempDir() string
 
 	GetAppState() *AppState
 	SaveAppState() error
 }
 
 // NewAppConfig makes a new app config
-func NewAppConfig(name, version, commit, date string, buildSource string, debuggingFlag bool) (*AppConfig, error) {
+func NewAppConfig(
+	name string,
+	version,
+	commit,
+	date string,
+	buildSource string,
+	debuggingFlag bool,
+	tempDir string,
+) (*AppConfig, error) {
 	configDir, err := findOrCreateConfigDir()
 	if err != nil && !os.IsPermission(err) {
 		return nil, err
@@ -74,15 +84,13 @@ func NewAppConfig(name, version, commit, date string, buildSource string, debugg
 		debuggingFlag = true
 	}
 
-	tempDir := filepath.Join(os.TempDir(), "lazygit")
-
 	appState, err := loadAppState()
 	if err != nil {
 		return nil, err
 	}
 
 	appConfig := &AppConfig{
-		Name:            "lazygit",
+		Name:            name,
 		Version:         version,
 		Commit:          commit,
 		BuildDate:       date,
@@ -123,7 +131,7 @@ func configDirForVendor(vendor string) string {
 
 func findOrCreateConfigDir() (string, error) {
 	folder := ConfigDir()
-	return folder, os.MkdirAll(folder, 0755)
+	return folder, os.MkdirAll(folder, 0o755)
 }
 
 func loadUserConfigWithDefaults(configFiles []string) (*UserConfig, error) {
@@ -160,7 +168,7 @@ func loadUserConfig(configFiles []string, base *UserConfig) (*UserConfig, error)
 		}
 
 		if err := yaml.Unmarshal(content, base); err != nil {
-			return nil, err
+			return nil, fmt.Errorf("The config at `%s` couldn't be parsed, please inspect it before opening up an issue.\n%w", path, err)
 		}
 	}
 
@@ -221,6 +229,10 @@ func (c *AppConfig) ReloadUserConfig() error {
 	return nil
 }
 
+func (c *AppConfig) GetTempDir() string {
+	return c.TempDir
+}
+
 func configFilePath(filename string) (string, error) {
 	folder, err := findOrCreateConfigDir()
 	if err != nil {
@@ -232,7 +244,7 @@ func configFilePath(filename string) (string, error) {
 
 var ConfigFilename = "config.yml"
 
-// ConfigFilename returns the filename of the deafult config file
+// ConfigFilename returns the filename of the default config file
 func (c *AppConfig) ConfigFilename() string {
 	return filepath.Join(c.UserConfigDir, ConfigFilename)
 }
@@ -249,7 +261,7 @@ func (c *AppConfig) SaveAppState() error {
 		return err
 	}
 
-	err = ioutil.WriteFile(filepath, marshalledAppState, 0644)
+	err = ioutil.WriteFile(filepath, marshalledAppState, 0o644)
 	if err != nil && os.IsPermission(err) {
 		// apparently when people have read-only permissions they prefer us to fail silently
 		return nil
