@@ -1,12 +1,10 @@
 package config
 
-const DefaultEditCommandTemplate = `{{editor}} {{filename}}`
-
 // GetPlatformDefaultConfig gets the defaults for the platform
 func GetPlatformDefaultConfig() OSConfig {
 	return OSConfig{
 		EditCommand:         ``,
-		EditCommandTemplate: DefaultEditCommandTemplate,
+		EditCommandTemplate: "",
 		OpenCommand:         `start "" {{filename}}`,
 		OpenLinkCommand:     `start "" {{link}}`,
 	}
