@@ -2,11 +2,95 @@ package gui
 
 import (
 	"github.com/jesseduffield/lazygit/pkg/gui/boxlayout"
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/utils"
+	"github.com/mattn/go-runewidth"
 )
 
+// In this file we use the boxlayout package, along with knowledge about the app's state,
+// to arrange the windows (i.e. panels) on the screen.
+
 const INFO_SECTION_PADDING = " "
 
+func (gui *Gui) getWindowDimensions(informationStr string, appStatus string) map[string]boxlayout.Dimensions {
+	width, height := gui.g.Size()
+
+	sideSectionWeight, mainSectionWeight := gui.getMidSectionWeights()
+
+	sidePanelsDirection := boxlayout.COLUMN
+	portraitMode := width <= 84 && height > 45
+	if portraitMode {
+		sidePanelsDirection = boxlayout.ROW
+	}
+
+	mainPanelsDirection := boxlayout.ROW
+	if gui.splitMainPanelSideBySide() {
+		mainPanelsDirection = boxlayout.COLUMN
+	}
+
+	extrasWindowSize := gui.getExtrasWindowSize(height)
+
+	showInfoSection := gui.c.UserConfig.Gui.ShowBottomLine || (gui.State.Searching.isSearching || gui.isAnyModeActive())
+	infoSectionSize := 0
+	if showInfoSection {
+		infoSectionSize = 1
+	}
+
+	root := &boxlayout.Box{
+		Direction: boxlayout.ROW,
+		Children: []*boxlayout.Box{
+			{
+				Direction: sidePanelsDirection,
+				Weight:    1,
+				Children: []*boxlayout.Box{
+					{
+						Direction:           boxlayout.ROW,
+						Weight:              sideSectionWeight,
+						ConditionalChildren: gui.sidePanelChildren,
+					},
+					{
+						Direction: boxlayout.ROW,
+						Weight:    mainSectionWeight,
+						Children: []*boxlayout.Box{
+							{
+								Direction: mainPanelsDirection,
+								Children:  gui.mainSectionChildren(),
+								Weight:    1,
+							},
+							{
+								Window: "extras",
+								Size:   extrasWindowSize,
+							},
+						},
+					},
+				},
+			},
+			{
+				Direction: boxlayout.COLUMN,
+				Size:      infoSectionSize,
+				Children:  gui.infoSectionChildren(informationStr, appStatus),
+			},
+		},
+	}
+
+	layerOneWindows := boxlayout.ArrangeWindows(root, 0, 0, width, height)
+	limitWindows := boxlayout.ArrangeWindows(&boxlayout.Box{Window: "limit"}, 0, 0, width, height)
+
+	return MergeMaps(layerOneWindows, limitWindows)
+}
+
+func MergeMaps[K comparable, V any](maps ...map[K]V) map[K]V {
+	result := map[K]V{}
+	for _, currMap := range maps {
+		for key, value := range currMap {
+			result[key] = value
+		}
+	}
+
+	return result
+}
+
 func (gui *Gui) mainSectionChildren() []*boxlayout.Box {
 	currentWindow := gui.currentWindow()
 
@@ -44,7 +128,7 @@ func (gui *Gui) getMidSectionWeights() (int, int) {
 	currentWindow := gui.currentWindow()
 
 	// we originally specified this as a ratio i.e. .20 would correspond to a weight of 1 against 4
-	sidePanelWidthRatio := gui.UserConfig.Gui.SidePanelWidth
+	sidePanelWidthRatio := gui.c.UserConfig.Gui.SidePanelWidth
 	// we could make this better by creating ratios like 2:3 rather than always 1:something
 	mainSectionWeight := int(1/sidePanelWidthRatio) - 1
 	sideSectionWeight := 1
@@ -73,7 +157,7 @@ func (gui *Gui) infoSectionChildren(informationStr string, appStatus string) []*
 		return []*boxlayout.Box{
 			{
 				Window: "searchPrefix",
-				Size:   len(SEARCH_PREFIX),
+				Size:   runewidth.StringWidth(SEARCH_PREFIX),
 			},
 			{
 				Window: "search",
@@ -88,7 +172,7 @@ func (gui *Gui) infoSectionChildren(informationStr string, appStatus string) []*
 		result = append(result,
 			&boxlayout.Box{
 				Window: "appStatus",
-				Size:   len(appStatus) + len(INFO_SECTION_PADDING),
+				Size:   runewidth.StringWidth(appStatus) + runewidth.StringWidth(INFO_SECTION_PADDING),
 			},
 		)
 	}
@@ -102,7 +186,7 @@ func (gui *Gui) infoSectionChildren(informationStr string, appStatus string) []*
 			{
 				Window: "information",
 				// unlike appStatus, informationStr has various colors so we need to decolorise before taking the length
-				Size: len(INFO_SECTION_PADDING) + len(utils.Decolorise(informationStr)),
+				Size: runewidth.StringWidth(INFO_SECTION_PADDING) + runewidth.StringWidth(utils.Decolorise(informationStr)),
 			},
 		}...,
 	)
@@ -115,7 +199,7 @@ func (gui *Gui) splitMainPanelSideBySide() bool {
 		return false
 	}
 
-	mainPanelSplitMode := gui.UserConfig.Gui.MainPanelSplitMode
+	mainPanelSplitMode := gui.c.UserConfig.Gui.MainPanelSplitMode
 	width, height := gui.g.Size()
 
 	switch mainPanelSplitMode {
@@ -138,76 +222,18 @@ func (gui *Gui) getExtrasWindowSize(screenHeight int) int {
 	}
 
 	var baseSize int
-	if gui.currentStaticContext().GetKey() == COMMAND_LOG_CONTEXT_KEY {
+	if gui.currentStaticContext().GetKey() == context.COMMAND_LOG_CONTEXT_KEY {
 		baseSize = 1000 // my way of saying 'fill the available space'
 	} else if screenHeight < 40 {
 		baseSize = 1
 	} else {
-		baseSize = gui.UserConfig.Gui.CommandLogSize
+		baseSize = gui.c.UserConfig.Gui.CommandLogSize
 	}
 
 	frameSize := 2
 	return baseSize + frameSize
 }
 
-func (gui *Gui) getWindowDimensions(informationStr string, appStatus string) map[string]boxlayout.Dimensions {
-	width, height := gui.g.Size()
-
-	sideSectionWeight, mainSectionWeight := gui.getMidSectionWeights()
-
-	sidePanelsDirection := boxlayout.COLUMN
-	portraitMode := width <= 84 && height > 45
-	if portraitMode {
-		sidePanelsDirection = boxlayout.ROW
-	}
-
-	mainPanelsDirection := boxlayout.ROW
-	if gui.splitMainPanelSideBySide() {
-		mainPanelsDirection = boxlayout.COLUMN
-	}
-
-	extrasWindowSize := gui.getExtrasWindowSize(height)
-
-	root := &boxlayout.Box{
-		Direction: boxlayout.ROW,
-		Children: []*boxlayout.Box{
-			{
-				Direction: sidePanelsDirection,
-				Weight:    1,
-				Children: []*boxlayout.Box{
-					{
-						Direction:           boxlayout.ROW,
-						Weight:              sideSectionWeight,
-						ConditionalChildren: gui.sidePanelChildren,
-					},
-					{
-						Direction: boxlayout.ROW,
-						Weight:    mainSectionWeight,
-						Children: []*boxlayout.Box{
-							{
-								Direction: mainPanelsDirection,
-								Children:  gui.mainSectionChildren(),
-								Weight:    1,
-							},
-							{
-								Window: "extras",
-								Size:   extrasWindowSize,
-							},
-						},
-					},
-				},
-			},
-			{
-				Direction: boxlayout.COLUMN,
-				Size:      1,
-				Children:  gui.infoSectionChildren(informationStr, appStatus),
-			},
-		},
-	}
-
-	return boxlayout.ArrangeWindows(root, 0, 0, width, height)
-}
-
 // The stash window by default only contains one line so that it's not hogging
 // too much space, but if you access it it should take up some space. This is
 // the default behaviour when accordion mode is NOT in effect. If it is in effect
@@ -259,7 +285,7 @@ func (gui *Gui) sidePanelChildren(width int, height int) []*boxlayout.Box {
 			fullHeightBox("stash"),
 		}
 	} else if height >= 28 {
-		accordionMode := gui.UserConfig.Gui.ExpandFocusedSidePanel
+		accordionMode := gui.c.UserConfig.Gui.ExpandFocusedSidePanel
 		accordionBox := func(defaultBox *boxlayout.Box) *boxlayout.Box {
 			if accordionMode && defaultBox.Window == currentWindow {
 				return &boxlayout.Box{
@@ -311,6 +337,10 @@ func (gui *Gui) sidePanelChildren(width int, height int) []*boxlayout.Box {
 	}
 }
 
+func (gui *Gui) getCyclableWindows() []string {
+	return []string{"status", "files", "branches", "commits", "stash"}
+}
+
 func (gui *Gui) currentSideWindowName() string {
 	// there is always one and only one cyclable context in the context stack. We'll look from top to bottom
 	gui.State.ContextManager.RLock()
@@ -320,7 +350,7 @@ func (gui *Gui) currentSideWindowName() string {
 		reversedIdx := len(gui.State.ContextManager.ContextStack) - 1 - idx
 		context := gui.State.ContextManager.ContextStack[reversedIdx]
 
-		if context.GetKind() == SIDE_CONTEXT {
+		if context.GetKind() == types.SIDE_CONTEXT {
 			return context.GetWindowName()
 		}
 	}
