@@ -3,54 +3,32 @@ package gui
 import (
 	"errors"
 	"fmt"
+	"sort"
+	"strings"
 
+	"github.com/jesseduffield/generics/maps"
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
-type ContextKind int
-
-const (
-	SIDE_CONTEXT ContextKind = iota
-	MAIN_CONTEXT
-	TEMPORARY_POPUP
-	PERSISTENT_POPUP
-	EXTRAS_CONTEXT
-)
-
-type OnFocusOpts struct {
-	ClickedViewName    string
-	ClickedViewLineIdx int
-}
-
-type Context interface {
-	HandleFocus(opts ...OnFocusOpts) error
-	HandleFocusLost() error
-	HandleRender() error
-	HandleRenderToMain() error
-	GetKind() ContextKind
-	GetViewName() string
-	GetWindowName() string
-	SetWindowName(string)
-	GetKey() ContextKey
-	SetParentContext(Context)
-
-	// we return a bool here to tell us whether or not the returned value just wraps a nil
-	GetParentContext() (Context, bool)
-	GetOptionsMap() map[string]string
-}
+// This file is for the management of contexts. There is a context stack such that
+// for example you might start off in the commits context and then open a menu, putting
+// you in the menu context. When contexts are activated/deactivated certain things need
+// to happen like showing/hiding views and rendering content.
 
 func (gui *Gui) popupViewNames() []string {
-	result := []string{}
-	for _, context := range gui.allContexts() {
-		if context.GetKind() == PERSISTENT_POPUP || context.GetKind() == TEMPORARY_POPUP {
-			result = append(result, context.GetViewName())
-		}
-	}
+	popups := slices.Filter(gui.State.Contexts.Flatten(), func(c types.Context) bool {
+		return c.GetKind() == types.PERSISTENT_POPUP || c.GetKind() == types.TEMPORARY_POPUP
+	})
 
-	return result
+	return slices.Map(popups, func(c types.Context) string {
+		return c.GetViewName()
+	})
 }
 
-func (gui *Gui) currentContextKeyIgnoringPopups() ContextKey {
+func (gui *Gui) currentContextKeyIgnoringPopups() types.ContextKey {
 	gui.State.ContextManager.RLock()
 	defer gui.State.ContextManager.RUnlock()
 
@@ -60,7 +38,7 @@ func (gui *Gui) currentContextKeyIgnoringPopups() ContextKey {
 		reversedIndex := len(stack) - 1 - i
 		context := stack[reversedIndex]
 		kind := stack[reversedIndex].GetKind()
-		if kind != TEMPORARY_POPUP && kind != PERSISTENT_POPUP {
+		if kind != types.TEMPORARY_POPUP && kind != types.PERSISTENT_POPUP {
 			return context.GetKey()
 		}
 	}
@@ -70,31 +48,40 @@ func (gui *Gui) currentContextKeyIgnoringPopups() ContextKey {
 
 // use replaceContext when you don't want to return to the original context upon
 // hitting escape: you want to go that context's parent instead.
-func (gui *Gui) replaceContext(c Context) error {
+func (gui *Gui) replaceContext(c types.Context) error {
+	if !c.IsFocusable() {
+		return nil
+	}
+
 	gui.State.ContextManager.Lock()
-	defer gui.State.ContextManager.Unlock()
 
 	if len(gui.State.ContextManager.ContextStack) == 0 {
-		gui.State.ContextManager.ContextStack = []Context{c}
+		gui.State.ContextManager.ContextStack = []types.Context{c}
 	} else {
 		// replace the last item with the given item
 		gui.State.ContextManager.ContextStack = append(gui.State.ContextManager.ContextStack[0:len(gui.State.ContextManager.ContextStack)-1], c)
 	}
 
+	defer gui.State.ContextManager.Unlock()
+
 	return gui.activateContext(c)
 }
 
-func (gui *Gui) pushContext(c Context, opts ...OnFocusOpts) error {
+func (gui *Gui) pushContext(c types.Context, opts ...types.OnFocusOpts) error {
 	// using triple dot but you should only ever pass one of these opt structs
 	if len(opts) > 1 {
 		return errors.New("cannot pass multiple opts to pushContext")
 	}
 
+	if !c.IsFocusable() {
+		return nil
+	}
+
 	gui.State.ContextManager.Lock()
 
 	// push onto stack
 	// if we are switching to a side context, remove all other contexts in the stack
-	if c.GetKind() == SIDE_CONTEXT {
+	if c.GetKind() == types.SIDE_CONTEXT {
 		for _, stackContext := range gui.State.ContextManager.ContextStack {
 			if stackContext.GetKey() != c.GetKey() {
 				if err := gui.deactivateContext(stackContext); err != nil {
@@ -103,7 +90,7 @@ func (gui *Gui) pushContext(c Context, opts ...OnFocusOpts) error {
 				}
 			}
 		}
-		gui.State.ContextManager.ContextStack = []Context{c}
+		gui.State.ContextManager.ContextStack = []types.Context{c}
 	} else if len(gui.State.ContextManager.ContextStack) == 0 || gui.currentContextWithoutLock().GetKey() != c.GetKey() {
 		// Do not append if the one at the end is the same context (e.g. opening a menu from a menu)
 		// In that case we'll just close the menu entirely when the user hits escape.
@@ -117,13 +104,11 @@ func (gui *Gui) pushContext(c Context, opts ...OnFocusOpts) error {
 	return gui.activateContext(c, opts...)
 }
 
-// asynchronous code idea: functions return an error via a channel, when done
-
 // pushContextWithView is to be used when you don't know which context you
 // want to switch to: you only know the view that you want to switch to. It will
 // look up the context currently active for that view and switch to that context
 func (gui *Gui) pushContextWithView(viewName string) error {
-	return gui.pushContext(gui.State.ViewContextMap[viewName])
+	return gui.c.PushContext(gui.State.ViewContextMap.Get(viewName))
 }
 
 func (gui *Gui) returnFromContext() error {
@@ -142,6 +127,8 @@ func (gui *Gui) returnFromContext() error {
 
 	gui.State.ContextManager.ContextStack = gui.State.ContextManager.ContextStack[:n]
 
+	gui.g.SetCurrentContext(string(newContext.GetKey()))
+
 	gui.State.ContextManager.Unlock()
 
 	if err := gui.deactivateContext(currentContext); err != nil {
@@ -151,7 +138,7 @@ func (gui *Gui) returnFromContext() error {
 	return gui.activateContext(newContext)
 }
 
-func (gui *Gui) deactivateContext(c Context) error {
+func (gui *Gui) deactivateContext(c types.Context) error {
 	view, _ := gui.g.View(c.GetViewName())
 
 	if view != nil && view.IsSearching() {
@@ -161,7 +148,9 @@ func (gui *Gui) deactivateContext(c Context) error {
 	}
 
 	// if we are the kind of context that is sent to back upon deactivation, we should do that
-	if view != nil && (c.GetKind() == TEMPORARY_POPUP || c.GetKind() == PERSISTENT_POPUP || c.GetKey() == COMMIT_FILES_CONTEXT_KEY) {
+	if view != nil &&
+		(c.GetKind() == types.TEMPORARY_POPUP ||
+			c.GetKind() == types.PERSISTENT_POPUP) {
 		view.Visible = false
 	}
 
@@ -175,13 +164,8 @@ func (gui *Gui) deactivateContext(c Context) error {
 // postRefreshUpdate is to be called on a context after the state that it depends on has been refreshed
 // if the context's view is set to another context we do nothing.
 // if the context's view is the current view we trigger a focus; re-selecting the current item.
-func (gui *Gui) postRefreshUpdate(c Context) error {
-	v, err := gui.g.View(c.GetViewName())
-	if err != nil {
-		return nil
-	}
-
-	if ContextKey(v.Context) != c.GetKey() {
+func (gui *Gui) postRefreshUpdate(c types.Context) error {
+	if gui.State.ViewContextMap.Get(c.GetViewName()).GetKey() != c.GetKey() {
 		return nil
 	}
 
@@ -198,29 +182,38 @@ func (gui *Gui) postRefreshUpdate(c Context) error {
 	return nil
 }
 
-func (gui *Gui) activateContext(c Context, opts ...OnFocusOpts) error {
+func (gui *Gui) activateContext(c types.Context, opts ...types.OnFocusOpts) error {
 	viewName := c.GetViewName()
 	v, err := gui.g.View(viewName)
 	if err != nil {
 		return err
 	}
-	originalViewContextKey := ContextKey(v.Context)
 
-	// ensure that any other window for which this view was active is now set to the default for that window.
-	gui.setViewAsActiveForWindow(v)
-
-	if viewName == "main" {
-		gui.changeMainViewsContext(c.GetKey())
-	} else {
-		gui.changeMainViewsContext(MAIN_NORMAL_CONTEXT_KEY)
+	originalViewContext := gui.State.ViewContextMap.Get(viewName)
+	var originalViewContextKey types.ContextKey = ""
+	if originalViewContext != nil {
+		originalViewContextKey = originalViewContext.GetKey()
 	}
 
+	gui.setWindowContext(c)
 	gui.setViewTabForContext(c)
 
+	if viewName == "main" {
+		gui.changeMainViewsContext(c)
+	} else {
+		gui.changeMainViewsContext(gui.State.Contexts.Normal)
+	}
+
+	gui.g.SetCurrentContext(string(c.GetKey()))
 	if _, err := gui.g.SetCurrentView(viewName); err != nil {
 		return err
 	}
 
+	desiredTitle := c.Title()
+	if desiredTitle != "" {
+		v.Title = desiredTitle
+	}
+
 	v.Visible = true
 
 	// if the new context's view was previously displaying another context, render the new context
@@ -230,7 +223,7 @@ func (gui *Gui) activateContext(c Context, opts ...OnFocusOpts) error {
 		}
 	}
 
-	v.Context = string(c.GetKey())
+	gui.ViewContextMapSet(viewName, c)
 
 	gui.g.Cursor = v.Editable
 
@@ -245,12 +238,31 @@ func (gui *Gui) activateContext(c Context, opts ...OnFocusOpts) error {
 		return err
 	}
 
-	// TODO: consider removing this and instead depending on the .Context field of views
-	gui.State.ViewContextMap[c.GetViewName()] = c
-
 	return nil
 }
 
+func (gui *Gui) optionsMapToString(optionsMap map[string]string) string {
+	options := maps.MapToSlice(optionsMap, func(key string, description string) string {
+		return key + ": " + description
+	})
+	sort.Strings(options)
+	return strings.Join(options, ", ")
+}
+
+func (gui *Gui) renderOptionsMap(optionsMap map[string]string) {
+	_ = gui.renderString(gui.Views.Options, gui.optionsMapToString(optionsMap))
+}
+
+// also setting context on view for now. We'll need to pick one of these two approaches to stick with.
+func (gui *Gui) ViewContextMapSet(viewName string, c types.Context) {
+	gui.State.ViewContextMap.Set(viewName, c)
+	view, err := gui.g.View(viewName)
+	if err != nil {
+		panic(err)
+	}
+	view.Context = string(c.GetKey())
+}
+
 // // currently unused
 // func (gui *Gui) renderContextStack() string {
 // 	result := ""
@@ -260,14 +272,14 @@ func (gui *Gui) activateContext(c Context, opts ...OnFocusOpts) error {
 // 	return result
 // }
 
-func (gui *Gui) currentContext() Context {
+func (gui *Gui) currentContext() types.Context {
 	gui.State.ContextManager.RLock()
 	defer gui.State.ContextManager.RUnlock()
 
 	return gui.currentContextWithoutLock()
 }
 
-func (gui *Gui) currentContextWithoutLock() Context {
+func (gui *Gui) currentContextWithoutLock() types.Context {
 	if len(gui.State.ContextManager.ContextStack) == 0 {
 		return gui.defaultSideContext()
 	}
@@ -277,16 +289,16 @@ func (gui *Gui) currentContextWithoutLock() Context {
 
 // the status panel is not yet a list context (and may never be), so this method is not
 // quite the same as currentSideContext()
-func (gui *Gui) currentSideListContext() IListContext {
+func (gui *Gui) currentSideListContext() types.IListContext {
 	context := gui.currentSideContext()
-	listContext, ok := context.(IListContext)
+	listContext, ok := context.(types.IListContext)
 	if !ok {
 		return nil
 	}
 	return listContext
 }
 
-func (gui *Gui) currentSideContext() Context {
+func (gui *Gui) currentSideContext() types.Context {
 	gui.State.ContextManager.RLock()
 	defer gui.State.ContextManager.RUnlock()
 
@@ -297,11 +309,11 @@ func (gui *Gui) currentSideContext() Context {
 		return gui.defaultSideContext()
 	}
 
-	// find the first context in the stack with the type of SIDE_CONTEXT
+	// find the first context in the stack with the type of types.SIDE_CONTEXT
 	for i := range stack {
 		context := stack[len(stack)-1-i]
 
-		if context.GetKind() == SIDE_CONTEXT {
+		if context.GetKind() == types.SIDE_CONTEXT {
 			return context
 		}
 	}
@@ -310,7 +322,7 @@ func (gui *Gui) currentSideContext() Context {
 }
 
 // static as opposed to popup
-func (gui *Gui) currentStaticContext() Context {
+func (gui *Gui) currentStaticContext() types.Context {
 	gui.State.ContextManager.RLock()
 	defer gui.State.ContextManager.RUnlock()
 
@@ -324,7 +336,7 @@ func (gui *Gui) currentStaticContext() Context {
 	for i := range stack {
 		context := stack[len(stack)-1-i]
 
-		if context.GetKind() != TEMPORARY_POPUP && context.GetKind() != PERSISTENT_POPUP {
+		if context.GetKind() != types.TEMPORARY_POPUP && context.GetKind() != types.PERSISTENT_POPUP {
 			return context
 		}
 	}
@@ -332,37 +344,19 @@ func (gui *Gui) currentStaticContext() Context {
 	return gui.defaultSideContext()
 }
 
-func (gui *Gui) defaultSideContext() Context {
+func (gui *Gui) defaultSideContext() types.Context {
 	if gui.State.Modes.Filtering.Active() {
-		return gui.State.Contexts.BranchCommits
+		return gui.State.Contexts.LocalCommits
 	} else {
 		return gui.State.Contexts.Files
 	}
 }
 
-// remove the need to do this: always use a mapping
-func (gui *Gui) setInitialViewContexts() {
-	// arguably we should only have our ViewContextMap and we should do away with
-	// contexts on views, or vice versa
-	for viewName, context := range gui.State.ViewContextMap {
-		// see if the view exists. If it does, set the context on it
-		view, err := gui.g.View(viewName)
-		if err != nil {
-			continue
-		}
-
-		view.Context = string(context.GetKey())
-	}
-}
-
 // getFocusLayout returns a manager function for when view gain and lose focus
 func (gui *Gui) getFocusLayout() func(g *gocui.Gui) error {
 	var previousView *gocui.View
 	return func(g *gocui.Gui) error {
 		newView := gui.g.CurrentView()
-		if err := gui.onViewFocusChange(); err != nil {
-			return err
-		}
 		// for now we don't consider losing focus to a popup panel as actually losing focus
 		if newView != previousView && !gui.isPopupPanel(newView.Name()) {
 			if err := gui.onViewFocusLost(previousView, newView); err != nil {
@@ -375,70 +369,53 @@ func (gui *Gui) getFocusLayout() func(g *gocui.Gui) error {
 	}
 }
 
-func (gui *Gui) onViewFocusChange() error {
-	gui.g.Mutexes.ViewsMutex.Lock()
-	defer gui.g.Mutexes.ViewsMutex.Unlock()
-
-	currentView := gui.g.CurrentView()
-	for _, view := range gui.g.Views() {
-		view.Highlight = view.Name() != "main" && view.Name() != "extras" && view == currentView
-	}
-	return nil
-}
-
 func (gui *Gui) onViewFocusLost(oldView *gocui.View, newView *gocui.View) error {
 	if oldView == nil {
 		return nil
 	}
 
+	oldView.Highlight = false
+
 	_ = oldView.SetOriginX(0)
 
-	if oldView == gui.Views.CommitFiles && newView != gui.Views.Main && newView != gui.Views.Secondary && newView != gui.Views.Search {
-		gui.resetWindowForView(gui.Views.CommitFiles)
-		if err := gui.deactivateContext(gui.State.Contexts.CommitFiles); err != nil {
-			return err
-		}
-	}
-
 	return nil
 }
 
+func (gui *Gui) TransientContexts() []types.Context {
+	return slices.Filter(gui.State.Contexts.Flatten(), func(context types.Context) bool {
+		return context.IsTransient()
+	})
+}
+
 // changeContext is a helper function for when we want to change a 'main' context
 // which currently just means a context that affects both the main and secondary views
 // other views can have their context changed directly but this function helps
 // keep the main and secondary views in sync
-func (gui *Gui) changeMainViewsContext(contextKey ContextKey) {
-	if gui.State.MainContext == contextKey {
+func (gui *Gui) changeMainViewsContext(c types.Context) {
+	if gui.State.MainContext == c.GetKey() {
 		return
 	}
 
-	switch contextKey {
-	case MAIN_NORMAL_CONTEXT_KEY, MAIN_PATCH_BUILDING_CONTEXT_KEY, MAIN_STAGING_CONTEXT_KEY, MAIN_MERGING_CONTEXT_KEY:
-		gui.Views.Main.Context = string(contextKey)
-		gui.Views.Secondary.Context = string(contextKey)
+	switch c.GetKey() {
+	case context.MAIN_NORMAL_CONTEXT_KEY, context.MAIN_PATCH_BUILDING_CONTEXT_KEY, context.MAIN_STAGING_CONTEXT_KEY, context.MAIN_MERGING_CONTEXT_KEY:
+		gui.ViewContextMapSet(gui.Views.Main.Name(), c)
+		gui.ViewContextMapSet(gui.Views.Secondary.Name(), c)
 	default:
-		panic(fmt.Sprintf("unknown context for main: %s", contextKey))
+		panic(fmt.Sprintf("unknown context for main: %s", c.GetKey()))
 	}
 
-	gui.State.MainContext = contextKey
+	gui.State.MainContext = c.GetKey()
 }
 
 func (gui *Gui) viewTabNames(viewName string) []string {
 	tabContexts := gui.State.ViewTabContextMap[viewName]
 
-	if len(tabContexts) == 0 {
-		return nil
-	}
-
-	result := make([]string, len(tabContexts))
-	for i, tabContext := range tabContexts {
-		result[i] = tabContext.tab
-	}
-
-	return result
+	return slices.Map(tabContexts, func(tabContext context.TabContext) string {
+		return tabContext.Tab
+	})
 }
 
-func (gui *Gui) setViewTabForContext(c Context) {
+func (gui *Gui) setViewTabForContext(c types.Context) {
 	// search for the context in our map and if we find it, set the tab for the corresponding view
 	tabContexts, ok := gui.State.ViewTabContextMap[c.GetViewName()]
 	if !ok {
@@ -446,51 +423,21 @@ func (gui *Gui) setViewTabForContext(c Context) {
 	}
 
 	for tabIndex, tabContext := range tabContexts {
-		for _, context := range tabContext.contexts {
-			if context.GetKey() == c.GetKey() {
-				// get the view, set the tab
-				v, err := gui.g.View(c.GetViewName())
-				if err != nil {
-					gui.Log.Error(err)
-					return
-				}
-				v.TabIndex = tabIndex
+		if tabContext.Context.GetKey() == c.GetKey() {
+			// get the view, set the tab
+			v, err := gui.g.View(c.GetViewName())
+			if err != nil {
+				gui.c.Log.Error(err)
 				return
 			}
+			v.TabIndex = tabIndex
+			return
 		}
 	}
 }
 
-type tabContext struct {
-	tab      string
-	contexts []Context
-}
-
-func (gui *Gui) mustContextForContextKey(contextKey ContextKey) Context {
-	context, ok := gui.contextForContextKey(contextKey)
-
-	if !ok {
-		panic(fmt.Sprintf("context not found for key %s", contextKey))
-	}
-
-	return context
-}
-
-func (gui *Gui) contextForContextKey(contextKey ContextKey) (Context, bool) {
-	for _, context := range gui.allContexts() {
-		if context.GetKey() == contextKey {
-			return context, true
-		}
-	}
-
-	return nil, false
-}
-
 func (gui *Gui) rerenderView(view *gocui.View) error {
-	contextKey := ContextKey(view.Context)
-	context := gui.mustContextForContextKey(contextKey)
-
-	return context.HandleRender()
+	return gui.State.ViewContextMap.Get(view.Name()).HandleRender()
 }
 
 func (gui *Gui) getSideContextSelectedItemId() string {
@@ -499,13 +446,12 @@ func (gui *Gui) getSideContextSelectedItemId() string {
 		return ""
 	}
 
-	item, ok := currentSideContext.GetSelectedItem()
+	return currentSideContext.GetSelectedItemId()
+}
 
-	if ok {
-		return item.ID()
-	}
-
-	return ""
+func (gui *Gui) isContextVisible(c types.Context) bool {
+	return gui.State.WindowViewNameMap[c.GetWindowName()] == c.GetViewName() &&
+		gui.State.ViewContextMap.Get(c.GetViewName()).GetKey() == c.GetKey()
 }
 
 // currently unused
