@@ -1,7 +1,9 @@
 package filetree
 
 import (
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
 type FileNode struct {
@@ -11,9 +13,10 @@ type FileNode struct {
 	CompressionLevel int    // equal to the number of forward slashes you'll see in the path when it's rendered in tree mode
 }
 
-var _ INode = &FileNode{}
-
-// methods satisfying ListItem interface
+var (
+	_ INode          = &FileNode{}
+	_ types.ListItem = &FileNode{}
+)
 
 func (s *FileNode) ID() string {
 	return s.GetPath()
@@ -39,20 +42,23 @@ func (s *FileNode) GetPath() string {
 	return s.Path
 }
 
-func (s *FileNode) GetChildren() []INode {
-	result := make([]INode, len(s.Children))
-	for i, child := range s.Children {
-		result[i] = child
+func (s *FileNode) GetPreviousPath() string {
+	if s.File != nil {
+		return s.File.GetPreviousPath()
 	}
+	return ""
+}
 
-	return result
+func (s *FileNode) GetChildren() []INode {
+	return slices.Map(s.Children, func(child *FileNode) INode {
+		return child
+	})
 }
 
 func (s *FileNode) SetChildren(children []INode) {
-	castChildren := make([]*FileNode, len(children))
-	for i, child := range children {
-		castChildren[i] = child.(*FileNode)
-	}
+	castChildren := slices.Map(children, func(child INode) *FileNode {
+		return child.(*FileNode)
+	})
 
 	s.Children = castChildren
 }
@@ -85,17 +91,14 @@ func (s *FileNode) Any(test func(node *FileNode) bool) bool {
 	})
 }
 
-func (n *FileNode) Flatten(collapsedPaths map[string]bool) []*FileNode {
+func (n *FileNode) Flatten(collapsedPaths *CollapsedPaths) []*FileNode {
 	results := flatten(n, collapsedPaths)
-	nodes := make([]*FileNode, len(results))
-	for i, result := range results {
-		nodes[i] = result.(*FileNode)
-	}
-
-	return nodes
+	return slices.Map(results, func(result INode) *FileNode {
+		return result.(*FileNode)
+	})
 }
 
-func (node *FileNode) GetNodeAtIndex(index int, collapsedPaths map[string]bool) *FileNode {
+func (node *FileNode) GetNodeAtIndex(index int, collapsedPaths *CollapsedPaths) *FileNode {
 	if node == nil {
 		return nil
 	}
@@ -109,11 +112,11 @@ func (node *FileNode) GetNodeAtIndex(index int, collapsedPaths map[string]bool)
 	return result.(*FileNode)
 }
 
-func (node *FileNode) GetIndexForPath(path string, collapsedPaths map[string]bool) (int, bool) {
+func (node *FileNode) GetIndexForPath(path string, collapsedPaths *CollapsedPaths) (int, bool) {
 	return getIndexForPath(node, path, collapsedPaths)
 }
 
-func (node *FileNode) Size(collapsedPaths map[string]bool) int {
+func (node *FileNode) Size(collapsedPaths *CollapsedPaths) int {
 	if node == nil {
 		return 0
 	}
@@ -144,12 +147,10 @@ func (node *FileNode) GetFilePathsMatching(test func(*models.File) bool) []strin
 
 func (s *FileNode) GetLeaves() []*FileNode {
 	leaves := getLeaves(s)
-	castLeaves := make([]*FileNode, len(leaves))
-	for i := range leaves {
-		castLeaves[i] = leaves[i].(*FileNode)
-	}
 
-	return castLeaves
+	return slices.Map(leaves, func(leaf INode) *FileNode {
+		return leaf.(*FileNode)
+	})
 }
 
 // extra methods
