@@ -2,11 +2,11 @@ package gui
 
 import (
 	"fmt"
-	"math"
 	"strings"
 
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
@@ -62,56 +62,17 @@ func (gui *Gui) prevScreenMode() error {
 	return gui.rerenderViewsWithScreenModeDependentContent()
 }
 
-func (gui *Gui) scrollUpView(view *gocui.View) error {
-	ox, oy := view.Origin()
-	newOy := int(math.Max(0, float64(oy-gui.UserConfig.Gui.ScrollHeight)))
-	return view.SetOrigin(ox, newOy)
+func (gui *Gui) scrollUpView(view *gocui.View) {
+	view.ScrollUp(gui.c.UserConfig.Gui.ScrollHeight)
 }
 
-func (gui *Gui) scrollDownView(view *gocui.View) error {
-	ox, oy := view.Origin()
-	scrollHeight := gui.linesToScrollDown(view)
-	if scrollHeight > 0 {
-		if err := view.SetOrigin(ox, oy+scrollHeight); err != nil {
-			return err
-		}
-	}
+func (gui *Gui) scrollDownView(view *gocui.View) {
+	scrollHeight := gui.c.UserConfig.Gui.ScrollHeight
+	view.ScrollDown(scrollHeight)
 
 	if manager, ok := gui.viewBufferManagerMap[view.Name()]; ok {
 		manager.ReadLines(scrollHeight)
 	}
-	return nil
-}
-
-func (gui *Gui) linesToScrollDown(view *gocui.View) int {
-	_, oy := view.Origin()
-	y := oy
-	canScrollPastBottom := gui.UserConfig.Gui.ScrollPastBottom
-	if !canScrollPastBottom {
-		_, sy := view.Size()
-		y += sy
-	}
-	scrollHeight := gui.UserConfig.Gui.ScrollHeight
-	scrollableLines := view.ViewLinesHeight() - y
-	if scrollableLines < 0 {
-		return 0
-	}
-
-	// margin is about how many lines must still appear if you scroll
-	// all the way down. In practice every file ends in a newline so it will really
-	// just show a single line
-	margin := 1
-	if canScrollPastBottom {
-		margin = 2
-	}
-	if scrollableLines-margin < scrollHeight {
-		scrollHeight = scrollableLines - margin
-	}
-	if oy+scrollHeight < 0 {
-		return 0
-	} else {
-		return scrollHeight
-	}
 }
 
 func (gui *Gui) scrollUpMain() error {
@@ -119,7 +80,9 @@ func (gui *Gui) scrollUpMain() error {
 		gui.State.Panels.Merging.UserVerticalScrolling = true
 	}
 
-	return gui.scrollUpView(gui.Views.Main)
+	gui.scrollUpView(gui.Views.Main)
+
+	return nil
 }
 
 func (gui *Gui) scrollDownMain() error {
@@ -127,7 +90,9 @@ func (gui *Gui) scrollDownMain() error {
 		gui.State.Panels.Merging.UserVerticalScrolling = true
 	}
 
-	return gui.scrollDownView(gui.Views.Main)
+	gui.scrollDownView(gui.Views.Main)
+
+	return nil
 }
 
 func (gui *Gui) scrollLeftMain() error {
@@ -152,11 +117,15 @@ func (gui *Gui) scrollRight(view *gocui.View) {
 }
 
 func (gui *Gui) scrollUpSecondary() error {
-	return gui.scrollUpView(gui.Views.Secondary)
+	gui.scrollUpView(gui.Views.Secondary)
+
+	return nil
 }
 
 func (gui *Gui) scrollDownSecondary() error {
-	return gui.scrollDownView(gui.Views.Secondary)
+	gui.scrollDownView(gui.Views.Secondary)
+
+	return nil
 }
 
 func (gui *Gui) scrollUpConfirmationPanel() error {
@@ -164,7 +133,9 @@ func (gui *Gui) scrollUpConfirmationPanel() error {
 		return nil
 	}
 
-	return gui.scrollUpView(gui.Views.Confirmation)
+	gui.scrollUpView(gui.Views.Confirmation)
+
+	return nil
 }
 
 func (gui *Gui) scrollDownConfirmationPanel() error {
@@ -172,67 +143,19 @@ func (gui *Gui) scrollDownConfirmationPanel() error {
 		return nil
 	}
 
-	return gui.scrollDownView(gui.Views.Confirmation)
+	gui.scrollDownView(gui.Views.Confirmation)
+
+	return nil
 }
 
 func (gui *Gui) handleRefresh() error {
-	return gui.refreshSidePanels(refreshOptions{mode: ASYNC})
-}
-
-func (gui *Gui) handleMouseDownMain() error {
-	if gui.popupPanelFocused() {
-		return nil
-	}
-
-	switch gui.currentSideContext() {
-	case gui.State.Contexts.Files:
-		// set filename, set primary/secondary selected, set line number, then switch context
-		// I'll need to know it was changed though.
-		// Could I pass something along to the context change?
-		return gui.enterFile(OnFocusOpts{ClickedViewName: "main", ClickedViewLineIdx: gui.Views.Main.SelectedLineIdx()})
-	case gui.State.Contexts.CommitFiles:
-		return gui.enterCommitFile(OnFocusOpts{ClickedViewName: "main", ClickedViewLineIdx: gui.Views.Main.SelectedLineIdx()})
-	}
-
-	return nil
-}
-
-func (gui *Gui) handleMouseDownSecondary() error {
-	if gui.popupPanelFocused() {
-		return nil
-	}
-
-	switch gui.g.CurrentView() {
-	case gui.Views.Files:
-		return gui.enterFile(OnFocusOpts{ClickedViewName: "secondary", ClickedViewLineIdx: gui.Views.Secondary.SelectedLineIdx()})
-	}
-
-	return nil
-}
-
-func (gui *Gui) fetch() (err error) {
-	gui.Mutexes.FetchMutex.Lock()
-	defer gui.Mutexes.FetchMutex.Unlock()
-
-	gui.logAction("Fetch")
-	err = gui.Git.Sync.Fetch(git_commands.FetchOptions{})
-
-	if err != nil && strings.Contains(err.Error(), "exit status 128") {
-		_ = gui.createErrorPanel(gui.Tr.PassUnameWrong)
-	}
-
-	_ = gui.refreshSidePanels(refreshOptions{scope: []RefreshableView{BRANCHES, COMMITS, REMOTES, TAGS}, mode: ASYNC})
-
-	return err
+	return gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
 }
 
 func (gui *Gui) backgroundFetch() (err error) {
-	gui.Mutexes.FetchMutex.Lock()
-	defer gui.Mutexes.FetchMutex.Unlock()
+	err = gui.git.Sync.Fetch(git_commands.FetchOptions{Background: true})
 
-	err = gui.Git.Sync.Fetch(git_commands.FetchOptions{Background: true})
-
-	_ = gui.refreshSidePanels(refreshOptions{scope: []RefreshableView{BRANCHES, COMMITS, REMOTES, TAGS}, mode: ASYNC})
+	_ = gui.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.BRANCHES, types.COMMITS, types.REMOTES, types.TAGS}, Mode: types.ASYNC})
 
 	return err
 }
@@ -245,14 +168,14 @@ func (gui *Gui) handleCopySelectedSideContextItemToClipboard() error {
 		return nil
 	}
 
-	gui.logAction(gui.Tr.Actions.CopyToClipboard)
-	if err := gui.OSCommand.CopyToClipboard(itemId); err != nil {
-		return gui.surfaceError(err)
+	gui.c.LogAction(gui.c.Tr.Actions.CopyToClipboard)
+	if err := gui.os.CopyToClipboard(itemId); err != nil {
+		return gui.c.Error(err)
 	}
 
 	truncatedItemId := utils.TruncateWithEllipsis(strings.Replace(itemId, "\n", " ", -1), 50)
 
-	gui.raiseToast(fmt.Sprintf("'%s' %s", truncatedItemId, gui.Tr.LcCopiedToClipboard))
+	gui.c.Toast(fmt.Sprintf("'%s' %s", truncatedItemId, gui.c.Tr.LcCopiedToClipboard))
 
 	return nil
 }
