@@ -5,9 +5,8 @@ import (
 	"io/ioutil"
 	"log"
 	"os"
-	"sync"
-
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/jesseduffield/gocui"
@@ -18,15 +17,19 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/config"
-	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
+	"github.com/jesseduffield/lazygit/pkg/gui/controllers/helpers"
 	"github.com/jesseduffield/lazygit/pkg/gui/lbl"
 	"github.com/jesseduffield/lazygit/pkg/gui/mergeconflicts"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/cherrypicking"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/diffing"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/filtering"
+	"github.com/jesseduffield/lazygit/pkg/gui/popup"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/authors"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/graph"
+	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
+	"github.com/jesseduffield/lazygit/pkg/gui/services/custom_commands"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/tasks"
@@ -54,13 +57,13 @@ const StartupPopupVersion = 5
 var OverlappingEdges = false
 
 type ContextManager struct {
-	ContextStack []Context
+	ContextStack []types.Context
 	sync.RWMutex
 }
 
-func NewContextManager(initialContext Context) ContextManager {
+func NewContextManager(initialContext types.Context) ContextManager {
 	return ContextManager{
-		ContextStack: []Context{initialContext},
+		ContextStack: []types.Context{initialContext},
 		RWMutex:      sync.RWMutex{},
 	}
 }
@@ -70,20 +73,21 @@ type Repo string
 // Gui wraps the gocui Gui object which handles rendering and events
 type Gui struct {
 	*common.Common
-	g         *gocui.Gui
-	Git       *commands.GitCommand
-	OSCommand *oscommands.OSCommand
+	g   *gocui.Gui
+	git *commands.GitCommand
+	os  *oscommands.OSCommand
 
 	// this is the state of the GUI for the current repo
-	State *guiState
+	State *GuiRepoState
+
+	CustomCommandsClient *custom_commands.Client
 
 	// this is a mapping of repos to gui states, so that we can restore the original
 	// gui state when returning from a subrepo
-	RepoStateMap         map[Repo]*guiState
+	RepoStateMap         map[Repo]*GuiRepoState
 	Config               config.AppConfigurer
 	Updater              *updates.Updater
 	statusManager        *statusManager
-	credentials          credentials
 	waitForIntro         sync.WaitGroup
 	fileWatcher          *fileWatcher
 	viewBufferManagerMap map[string]*tasks.ViewBufferManager
@@ -101,7 +105,7 @@ type Gui struct {
 
 	// when you enter into a submodule we'll append the superproject's path to this array
 	// so that you can return to the superproject
-	RepoPathStack []string
+	RepoPathStack *utils.StringStack
 
 	// this tells us whether our views have been initially set up
 	ViewsSetup bool
@@ -121,21 +125,79 @@ type Gui struct {
 
 	suggestionsAsyncHandler *tasks.AsyncHandler
 
-	PopupHandler PopupHandler
+	PopupHandler types.IPopupHandler
 
 	IsNewRepo bool
+
+	// flag as to whether or not the diff view should ignore whitespace
+	IgnoreWhitespaceInDiffView bool
+
+	// we use this to decide whether we'll return to the original directory that
+	// lazygit was opened in, or if we'll retain the one we're currently in.
+	RetainOriginalDir bool
+
+	PrevLayout PrevLayout
+
+	// this is the initial dir we are in upon opening lazygit. We hold onto this
+	// in case we want to restore it before quitting for users who have set up
+	// the feature for changing directory upon quit.
+	// The reason we don't just wait until quit time to handle changing directories
+	// is because some users want to keep track of the current lazygit directory in an outside
+	// process
+	InitialDir string
+
+	c       *types.HelperCommon
+	helpers *helpers.Helpers
 }
 
-type listPanelState struct {
-	SelectedLineIdx int
+// we keep track of some stuff from one render to the next to see if certain
+// things have changed
+type PrevLayout struct {
+	Information string
+	MainWidth   int
+	MainHeight  int
 }
 
-func (h *listPanelState) SetSelectedLineIdx(value int) {
-	h.SelectedLineIdx = value
-}
+type GuiRepoState struct {
+	Model *types.Model
+	Modes *types.Modes
 
-func (h *listPanelState) GetSelectedLineIdx() int {
-	return h.SelectedLineIdx
+	// Suggestions will sometimes appear when typing into a prompt
+	Suggestions []*types.Suggestion
+
+	Updating       bool
+	Panels         *panelStates
+	SplitMainPanel bool
+	LimitCommits   bool
+
+	IsRefreshingFiles bool
+	Searching         searchingState
+	Ptmx              *os.File
+	StartupStage      StartupStage // Allows us to not load everything at once
+
+	MainContext       types.ContextKey // used to keep the main and secondary views' contexts in sync
+	ContextManager    ContextManager
+	Contexts          *context.ContextTree
+	ViewContextMap    *context.ViewContextMap
+	ViewTabContextMap map[string][]context.TabContext
+
+	// WindowViewNameMap is a mapping of windows to the current view of that window.
+	// Some views move between windows for example the commitFiles view and when cycling through
+	// side windows we need to know which view to give focus to for a given window
+	WindowViewNameMap map[string]string
+
+	// tells us whether we've set up our views for the current repo. We'll need to
+	// do this whenever we switch back and forth between repos to get the views
+	// back in sync with the repo state
+	ViewsSetup bool
+
+	// we store a commit message in this field if we've escaped the commit message
+	// panel without committing or if our commit failed
+	savedCommitMessage string
+
+	ScreenMode WindowMaximisation
+
+	CurrentPopupOpts *types.CreatePopupPanelOpts
 }
 
 // for now the staging panel state, unlike the other panel states, is going to be
@@ -154,109 +216,11 @@ type MergingPanelState struct {
 	UserVerticalScrolling bool
 }
 
-type filePanelState struct {
-	listPanelState
-}
-
-// TODO: consider splitting this out into the window and the branches view
-type branchPanelState struct {
-	listPanelState
-}
-
-type remotePanelState struct {
-	listPanelState
-}
-
-type remoteBranchesState struct {
-	listPanelState
-}
-
-type tagsPanelState struct {
-	listPanelState
-}
-
-type commitPanelState struct {
-	listPanelState
-
-	LimitCommits bool
-}
-
-type reflogCommitPanelState struct {
-	listPanelState
-}
-
-type subCommitPanelState struct {
-	listPanelState
-
-	// e.g. name of branch whose commits we're looking at
-	refName string
-}
-
-type stashPanelState struct {
-	listPanelState
-}
-
-type menuPanelState struct {
-	listPanelState
-	OnPress func() error
-}
-
-type commitFilesPanelState struct {
-	listPanelState
-
-	// this is the SHA of the commit or the stash index of the stash.
-	// Not sure if ref is actually the right word here
-	refName   string
-	canRebase bool
-}
-
-type submodulePanelState struct {
-	listPanelState
-}
-
-type suggestionsPanelState struct {
-	listPanelState
-}
-
+// as we move things to the new context approach we're going to eventually
+// remove this struct altogether and store this state on the contexts.
 type panelStates struct {
-	Files          *filePanelState
-	Branches       *branchPanelState
-	Remotes        *remotePanelState
-	RemoteBranches *remoteBranchesState
-	Tags           *tagsPanelState
-	Commits        *commitPanelState
-	ReflogCommits  *reflogCommitPanelState
-	SubCommits     *subCommitPanelState
-	Stash          *stashPanelState
-	Menu           *menuPanelState
-	LineByLine     *LblPanelState
-	Merging        *MergingPanelState
-	CommitFiles    *commitFilesPanelState
-	Submodules     *submodulePanelState
-	Suggestions    *suggestionsPanelState
-}
-
-type Views struct {
-	Status        *gocui.View
-	Files         *gocui.View
-	Branches      *gocui.View
-	Commits       *gocui.View
-	Stash         *gocui.View
-	Main          *gocui.View
-	Secondary     *gocui.View
-	Options       *gocui.View
-	Confirmation  *gocui.View
-	Menu          *gocui.View
-	Credentials   *gocui.View
-	CommitMessage *gocui.View
-	CommitFiles   *gocui.View
-	Information   *gocui.View
-	AppStatus     *gocui.View
-	Search        *gocui.View
-	SearchPrefix  *gocui.View
-	Limit         *gocui.View
-	Suggestions   *gocui.View
-	Extras        *gocui.View
+	LineByLine *LblPanelState
+	Merging    *MergingPanelState
 }
 
 type searchingState struct {
@@ -273,88 +237,39 @@ const (
 	COMPLETE
 )
 
-type Modes struct {
-	Filtering     filtering.Filtering
-	CherryPicking cherrypicking.CherryPicking
-	Diffing       diffing.Diffing
-}
-
+// if you add a new mutex here be sure to instantiate it. We're using pointers to
+// mutexes so that we can pass the mutexes to controllers.
 type guiMutexes struct {
-	RefreshingFilesMutex  sync.Mutex
-	RefreshingStatusMutex sync.Mutex
-	FetchMutex            sync.Mutex
-	BranchCommitsMutex    sync.Mutex
-	LineByLinePanelMutex  sync.Mutex
-	SubprocessMutex       sync.Mutex
+	RefreshingFilesMutex  *sync.Mutex
+	RefreshingStatusMutex *sync.Mutex
+	SyncMutex             *sync.Mutex
+	LocalCommitsMutex     *sync.Mutex
+	LineByLinePanelMutex  *sync.Mutex
+	SubprocessMutex       *sync.Mutex
+	PopupMutex            *sync.Mutex
 }
 
-type guiState struct {
-	// the file panels (files and commit files) can render as a tree, so we have
-	// managers for them which handle rendering a flat list of files in tree form
-	FileTreeViewModel       *filetree.FileTreeViewModel
-	CommitFileTreeViewModel *filetree.CommitFileTreeViewModel
+func (gui *Gui) onNewRepo(startArgs types.StartArgs, reuseState bool) error {
+	var err error
+	gui.git, err = commands.NewGitCommand(
+		gui.Common,
+		gui.os,
+		git_config.NewStdCachedGitConfig(gui.Log),
+		gui.Mutexes.SyncMutex,
+	)
+	if err != nil {
+		return err
+	}
 
-	Submodules   []*models.SubmoduleConfig
-	Branches     []*models.Branch
-	Commits      []*models.Commit
-	StashEntries []*models.StashEntry
-	// Suggestions will sometimes appear when typing into a prompt
-	Suggestions []*types.Suggestion
-	// FilteredReflogCommits are the ones that appear in the reflog panel.
-	// when in filtering mode we only include the ones that match the given path
-	FilteredReflogCommits []*models.Commit
-	// ReflogCommits are the ones used by the branches panel to obtain recency values
-	// if we're not in filtering mode, CommitFiles and FilteredReflogCommits will be
-	// one and the same
-	ReflogCommits  []*models.Commit
-	SubCommits     []*models.Commit
-	Remotes        []*models.Remote
-	RemoteBranches []*models.RemoteBranch
-	Tags           []*models.Tag
-	MenuItems      []*menuItem
-	BisectInfo     *git_commands.BisectInfo
+	gui.resetState(startArgs, reuseState)
 
-	Updating          bool
-	Panels            *panelStates
-	SplitMainPanel    bool
-	MainContext       ContextKey // used to keep the main and secondary views' contexts in sync
-	RetainOriginalDir bool
-	IsRefreshingFiles bool
-	Searching         searchingState
-	// if this is true, we'll load our commits using `git log --all`
-	ShowWholeGitGraph bool
-	ScreenMode        WindowMaximisation
-	Ptmx              *os.File
-	PrevMainWidth     int
-	PrevMainHeight    int
-	OldInformation    string
-	StartupStage      StartupStage // Allows us to not load everything at once
+	gui.resetControllers()
 
-	Modes Modes
+	if err := gui.resetKeybindings(); err != nil {
+		return err
+	}
 
-	ContextManager    ContextManager
-	Contexts          ContextTree
-	ViewContextMap    map[string]Context
-	ViewTabContextMap map[string][]tabContext
-
-	// WindowViewNameMap is a mapping of windows to the current view of that window.
-	// Some views move between windows for example the commitFiles view and when cycling through
-	// side windows we need to know which view to give focus to for a given window
-	WindowViewNameMap map[string]string
-
-	// tells us whether we've set up our views for the current repo. We'll need to
-	// do this whenever we switch back and forth between repos to get the views
-	// back in sync with the repo state
-	ViewsSetup bool
-
-	// flag as to whether or not the diff view should ignore whitespace
-	IgnoreWhitespaceInDiffView bool
-
-	// for displaying suggestions while typing in a file name
-	FilesTrie *patricia.Trie
-
-	// this is the message of the last failed commit attempt
-	failedCommitMessage string
+	return nil
 }
 
 // reuseState determines if we pull the repo state from our repo state map or
@@ -366,7 +281,7 @@ type guiState struct {
 // it gets a bit confusing to land back in the status panel when visiting a repo
 // you've already switched from. There's no doubt some easy way to make the UX
 // optimal for all cases but I'm too lazy to think about what that is right now
-func (gui *Gui) resetState(filterPath string, reuseState bool) {
+func (gui *Gui) resetState(startArgs types.StartArgs, reuseState bool) {
 	currentDir, err := os.Getwd()
 
 	if reuseState {
@@ -374,70 +289,109 @@ func (gui *Gui) resetState(filterPath string, reuseState bool) {
 			if state := gui.RepoStateMap[Repo(currentDir)]; state != nil {
 				gui.State = state
 				gui.State.ViewsSetup = false
+
+				// setting this to nil so we don't get stuck based on a popup that was
+				// previously opened
+				gui.Mutexes.PopupMutex.Lock()
+				gui.State.CurrentPopupOpts = nil
+				gui.Mutexes.PopupMutex.Unlock()
+
+				gui.syncViewContexts()
 				return
 			}
 		} else {
-			gui.Log.Error(err)
+			gui.c.Log.Error(err)
 		}
 	}
 
-	showTree := gui.UserConfig.Gui.ShowFileTree
+	contextTree := gui.contextTree()
 
-	contexts := gui.contextTree()
+	initialContext := initialContext(contextTree, startArgs)
+	initialScreenMode := initialScreenMode(startArgs)
 
-	screenMode := SCREEN_NORMAL
-	initialContext := contexts.Files
-	if filterPath != "" {
-		screenMode = SCREEN_HALF
-		initialContext = contexts.BranchCommits
+	viewContextMap := context.NewViewContextMap()
+	for viewName, context := range initialViewContextMapping(contextTree) {
+		viewContextMap.Set(viewName, context)
 	}
 
-	gui.State = &guiState{
-		FileTreeViewModel:       filetree.NewFileTreeViewModel(make([]*models.File, 0), gui.Log, showTree),
-		CommitFileTreeViewModel: filetree.NewCommitFileTreeViewModel(make([]*models.CommitFile, 0), gui.Log, showTree),
-		Commits:                 make([]*models.Commit, 0),
-		FilteredReflogCommits:   make([]*models.Commit, 0),
-		ReflogCommits:           make([]*models.Commit, 0),
-		StashEntries:            make([]*models.StashEntry, 0),
-		BisectInfo:              gui.Git.Bisect.GetInfo(),
+	gui.State = &GuiRepoState{
+		Model: &types.Model{
+			CommitFiles:           nil,
+			Files:                 make([]*models.File, 0),
+			Commits:               make([]*models.Commit, 0),
+			StashEntries:          make([]*models.StashEntry, 0),
+			FilteredReflogCommits: make([]*models.Commit, 0),
+			ReflogCommits:         make([]*models.Commit, 0),
+			BisectInfo:            git_commands.NewNullBisectInfo(),
+			FilesTrie:             patricia.NewTrie(),
+		},
+
 		Panels: &panelStates{
-			// TODO: work out why some of these are -1 and some are 0. Last time I checked there was a good reason but I'm less certain now
-			Files:          &filePanelState{listPanelState{SelectedLineIdx: -1}},
-			Submodules:     &submodulePanelState{listPanelState{SelectedLineIdx: -1}},
-			Branches:       &branchPanelState{listPanelState{SelectedLineIdx: 0}},
-			Remotes:        &remotePanelState{listPanelState{SelectedLineIdx: 0}},
-			RemoteBranches: &remoteBranchesState{listPanelState{SelectedLineIdx: -1}},
-			Tags:           &tagsPanelState{listPanelState{SelectedLineIdx: -1}},
-			Commits:        &commitPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, LimitCommits: true},
-			ReflogCommits:  &reflogCommitPanelState{listPanelState{SelectedLineIdx: 0}},
-			SubCommits:     &subCommitPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, refName: ""},
-			CommitFiles:    &commitFilesPanelState{listPanelState: listPanelState{SelectedLineIdx: -1}, refName: ""},
-			Stash:          &stashPanelState{listPanelState{SelectedLineIdx: -1}},
-			Menu:           &menuPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, OnPress: nil},
-			Suggestions:    &suggestionsPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}},
 			Merging: &MergingPanelState{
 				State:                 mergeconflicts.NewState(),
 				UserVerticalScrolling: false,
 			},
 		},
 		Ptmx: nil,
-		Modes: Modes{
-			Filtering:     filtering.New(filterPath),
+		Modes: &types.Modes{
+			Filtering:     filtering.New(startArgs.FilterPath),
 			CherryPicking: cherrypicking.New(),
 			Diffing:       diffing.New(),
 		},
-		ViewContextMap:    contexts.initialViewContextMap(),
-		ViewTabContextMap: contexts.initialViewTabContextMap(),
-		ScreenMode:        screenMode,
+		ViewContextMap:    viewContextMap,
+		ViewTabContextMap: gui.initialViewTabContextMap(contextTree),
+		ScreenMode:        initialScreenMode,
 		// TODO: put contexts in the context manager
 		ContextManager: NewContextManager(initialContext),
-		Contexts:       contexts,
-		FilesTrie:      patricia.NewTrie(),
+		Contexts:       contextTree,
 	}
 
+	gui.syncViewContexts()
+
 	gui.RepoStateMap[Repo(currentDir)] = gui.State
 }
 
+func initialScreenMode(startArgs types.StartArgs) WindowMaximisation {
+	if startArgs.FilterPath != "" || startArgs.GitArg != types.GitArgNone {
+		return SCREEN_HALF
+	} else {
+		return SCREEN_NORMAL
+	}
+}
+
+func initialContext(contextTree *context.ContextTree, startArgs types.StartArgs) types.IListContext {
+	var initialContext types.IListContext = contextTree.Files
+
+	if startArgs.FilterPath != "" {
+		initialContext = contextTree.LocalCommits
+	} else if startArgs.GitArg != types.GitArgNone {
+		switch startArgs.GitArg {
+		case types.GitArgStatus:
+			initialContext = contextTree.Files
+		case types.GitArgBranch:
+			initialContext = contextTree.Branches
+		case types.GitArgLog:
+			initialContext = contextTree.LocalCommits
+		case types.GitArgStash:
+			initialContext = contextTree.Stash
+		default:
+			panic("unhandled git arg")
+		}
+	}
+
+	return initialContext
+}
+
+func (gui *Gui) syncViewContexts() {
+	for viewName, context := range gui.State.ViewContextMap.Entries() {
+		view, err := gui.g.View(viewName)
+		if err != nil {
+			panic(err)
+		}
+		view.Context = string(context.GetKey())
+	}
+}
+
 // for now the split view will always be on
 // NewGui builds a new gui handler
 func NewGui(
@@ -445,8 +399,8 @@ func NewGui(
 	config config.AppConfigurer,
 	gitConfig git_config.IGitConfig,
 	updater *updates.Updater,
-	filterPath string,
 	showRecentRepos bool,
+	initialDir string,
 ) (*Gui, error) {
 	gui := &Gui{
 		Common:                  cmn,
@@ -455,8 +409,8 @@ func NewGui(
 		statusManager:           &statusManager{},
 		viewBufferManagerMap:    map[string]*tasks.ViewBufferManager{},
 		showRecentRepos:         showRecentRepos,
-		RepoPathStack:           []string{},
-		RepoStateMap:            map[Repo]*guiState{},
+		RepoPathStack:           &utils.StringStack{},
+		RepoStateMap:            map[Repo]*GuiRepoState{},
 		CmdLog:                  []string{},
 		suggestionsAsyncHandler: tasks.NewAsyncHandler(),
 
@@ -464,35 +418,53 @@ func NewGui(
 		// but now we do it via state. So we need to still support the config for the
 		// sake of backwards compatibility. We're making use of short circuiting here
 		ShowExtrasWindow: cmn.UserConfig.Gui.ShowCommandLog && !config.GetAppState().HideCommandLog,
+		Mutexes: guiMutexes{
+			RefreshingFilesMutex:  &sync.Mutex{},
+			RefreshingStatusMutex: &sync.Mutex{},
+			SyncMutex:             &sync.Mutex{},
+			LocalCommitsMutex:     &sync.Mutex{},
+			LineByLinePanelMutex:  &sync.Mutex{},
+			SubprocessMutex:       &sync.Mutex{},
+			PopupMutex:            &sync.Mutex{},
+		},
+		InitialDir: initialDir,
 	}
 
-	guiIO := oscommands.NewGuiIO(
-		cmn.Log,
-		gui.logCommand,
-		gui.getCmdWriter,
-		gui.promptUserForCredential,
-	)
-
-	osCommand := oscommands.NewOSCommand(cmn, oscommands.GetPlatform(), guiIO)
-
-	gui.OSCommand = osCommand
-	var err error
-	gui.Git, err = commands.NewGitCommand(
-		cmn,
-		osCommand,
-		gitConfig,
-	)
-	if err != nil {
-		return nil, err
-	}
-
-	gui.resetState(filterPath, false)
-
 	gui.watchFilesForChanges()
 
-	gui.PopupHandler = &RealPopupHandler{gui: gui}
+	gui.PopupHandler = popup.NewPopupHandler(
+		cmn,
+		gui.createPopupPanel,
+		func() error { return gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC}) },
+		func() error { return gui.closeConfirmationPrompt(false) },
+		gui.createMenu,
+		gui.withWaitingStatus,
+		gui.toast,
+		func() string { return gui.Views.Confirmation.TextArea.GetContent() },
+	)
+
+	guiCommon := &guiCommon{gui: gui, IPopupHandler: gui.PopupHandler}
+	helperCommon := &types.HelperCommon{IGuiCommon: guiCommon, Common: cmn}
+
+	credentialsHelper := helpers.NewCredentialsHelper(helperCommon)
+
+	guiIO := oscommands.NewGuiIO(
+		cmn.Log,
+		gui.LogCommand,
+		gui.getCmdWriter,
+		credentialsHelper.PromptUserForCredential,
+	)
+
+	osCommand := oscommands.NewOSCommand(cmn, config, oscommands.GetPlatform(), guiIO)
+
+	gui.os = osCommand
+
+	// storing this stuff on the gui for now to ease refactoring
+	// TODO: reset these controllers upon changing repos due to state changing
+	gui.c = helperCommon
 
 	authors.SetCustomAuthors(gui.UserConfig.Gui.AuthorColors)
+	icons.SetIconEnabled(gui.UserConfig.Gui.ShowIcons)
 	presentation.SetCustomBranches(gui.UserConfig.Gui.BranchColors)
 
 	return gui, nil
@@ -504,8 +476,7 @@ var RuneReplacements = map[rune]string{
 	graph.CommitSymbol: "o",
 }
 
-// Run setup the gui with keybindings and start the mainloop
-func (gui *Gui) Run() error {
+func (gui *Gui) initGocui() (*gocui.Gui, error) {
 	recordEvents := recordingEvents()
 	playMode := gocui.NORMAL
 	if recordEvents {
@@ -515,20 +486,70 @@ func (gui *Gui) Run() error {
 	}
 
 	g, err := gocui.NewGui(gocui.OutputTrue, OverlappingEdges, playMode, headless(), RuneReplacements)
+	if err != nil {
+		return nil, err
+	}
+
+	return g, nil
+}
+
+func (gui *Gui) initialViewTabContextMap(contextTree *context.ContextTree) map[string][]context.TabContext {
+	return map[string][]context.TabContext{
+		"branches": {
+			{
+				Tab:     gui.c.Tr.LocalBranchesTitle,
+				Context: contextTree.Branches,
+			},
+			{
+				Tab:     gui.c.Tr.RemotesTitle,
+				Context: contextTree.Remotes,
+			},
+			{
+				Tab:     gui.c.Tr.TagsTitle,
+				Context: contextTree.Tags,
+			},
+		},
+		"commits": {
+			{
+				Tab:     gui.c.Tr.CommitsTitle,
+				Context: contextTree.LocalCommits,
+			},
+			{
+				Tab:     gui.c.Tr.ReflogCommitsTitle,
+				Context: contextTree.ReflogCommits,
+			},
+		},
+		"files": {
+			{
+				Tab:     gui.c.Tr.FilesTitle,
+				Context: contextTree.Files,
+			},
+			{
+				Tab:     gui.c.Tr.SubmodulesTitle,
+				Context: contextTree.Submodules,
+			},
+		},
+	}
+}
+
+// Run: setup the gui with keybindings and start the mainloop
+func (gui *Gui) Run(startArgs types.StartArgs) error {
+	g, err := gui.initGocui()
 	if err != nil {
 		return err
 	}
 
-	gui.g = g // TODO: always use gui.g rather than passing g around everywhere
-	defer g.Close()
+	gui.g = g
+	defer gui.g.Close()
 
 	if replaying() {
-		g.RecordingConfig = gocui.RecordingConfig{
+		gui.g.RecordingConfig = gocui.RecordingConfig{
 			Speed:  getRecordingSpeed(),
 			Leeway: 100,
 		}
 
-		g.Recording, err = gui.loadRecording()
+		var err error
+		gui.g.Recording, err = gui.loadRecording()
 		if err != nil {
 			return err
 		}
@@ -539,45 +560,69 @@ func (gui *Gui) Run() error {
 		})
 	}
 
-	g.OnSearchEscape = gui.onSearchEscape
+	gui.g.OnSearchEscape = gui.onSearchEscape
 	if err := gui.Config.ReloadUserConfig(); err != nil {
 		return nil
 	}
 	userConfig := gui.UserConfig
-	g.SearchEscapeKey = gui.getKey(userConfig.Keybinding.Universal.Return)
-	g.NextSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.NextMatch)
-	g.PrevSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.PrevMatch)
+	gui.g.SearchEscapeKey = gui.getKey(userConfig.Keybinding.Universal.Return)
+	gui.g.NextSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.NextMatch)
+	gui.g.PrevSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.PrevMatch)
 
-	g.ShowListFooter = userConfig.Gui.ShowListFooter
+	gui.g.ShowListFooter = userConfig.Gui.ShowListFooter
 
 	if userConfig.Gui.MouseEvents {
-		g.Mouse = true
+		gui.g.Mouse = true
 	}
 
 	if err := gui.setColorScheme(); err != nil {
 		return err
 	}
 
-	gui.waitForIntro.Add(1)
-	if gui.UserConfig.Git.AutoFetch {
-		go utils.Safe(gui.startBackgroundFetch)
+	gui.g.SetManager(gocui.ManagerFunc(gui.layout), gocui.ManagerFunc(gui.getFocusLayout()))
+
+	if err := gui.createAllViews(); err != nil {
+		return err
 	}
 
-	gui.goEvery(time.Second*time.Duration(userConfig.Refresher.RefreshInterval), gui.stopChan, gui.refreshFilesAndSubmodules)
+	// onNewRepo must be called after g.SetManager because SetManager deletes keybindings
+	if err := gui.onNewRepo(startArgs, false); err != nil {
+		return err
+	}
 
-	g.SetManager(gocui.ManagerFunc(gui.layout), gocui.ManagerFunc(gui.getFocusLayout()))
+	gui.waitForIntro.Add(1)
 
-	gui.Log.Info("starting main loop")
+	if userConfig.Git.AutoFetch {
+		fetchInterval := userConfig.Refresher.FetchInterval
+		if fetchInterval > 0 {
+			go utils.Safe(gui.startBackgroundFetch)
+		} else {
+			gui.c.Log.Errorf(
+				"Value of config option 'refresher.fetchInterval' (%d) is invalid, disabling auto-fetch",
+				fetchInterval)
+		}
+	}
 
-	err = g.MainLoop()
-	return err
+	if userConfig.Git.AutoRefresh {
+		refreshInterval := userConfig.Refresher.RefreshInterval
+		if refreshInterval > 0 {
+			gui.goEvery(time.Second*time.Duration(refreshInterval), gui.stopChan, gui.refreshFilesAndSubmodules)
+		} else {
+			gui.c.Log.Errorf(
+				"Value of config option 'refresher.refreshInterval' (%d) is invalid, disabling auto-refresh",
+				refreshInterval)
+		}
+	}
+
+	gui.c.Log.Info("starting main loop")
+
+	return gui.g.MainLoop()
 }
 
-// RunAndHandleError
-func (gui *Gui) RunAndHandleError() error {
+func (gui *Gui) RunAndHandleError(startArgs types.StartArgs) error {
 	gui.stopChan = make(chan struct{})
 	return utils.SafeWithError(func() error {
-		if err := gui.Run(); err != nil {
+		if err := gui.Run(startArgs); err != nil {
 			for _, manager := range gui.viewBufferManagerMap {
 				manager.Close()
 			}
@@ -590,7 +635,11 @@ func (gui *Gui) RunAndHandleError() error {
 
 			switch err {
 			case gocui.ErrQuit:
-				if !gui.State.RetainOriginalDir {
+				if gui.RetainOriginalDir {
+					if err := gui.recordDirectory(gui.InitialDir); err != nil {
+						return err
+					}
+				} else {
 					if err := gui.recordCurrentDirectory(); err != nil {
 						return err
 					}
@@ -618,7 +667,7 @@ func (gui *Gui) runSubprocessWithSuspenseAndRefresh(subprocess oscommands.ICmdOb
 		return err
 	}
 
-	if err := gui.refreshSidePanels(refreshOptions{mode: ASYNC}); err != nil {
+	if err := gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC}); err != nil {
 		return err
 	}
 
@@ -639,7 +688,7 @@ func (gui *Gui) runSubprocessWithSuspense(subprocess oscommands.ICmdObj) (bool,
 	}
 
 	if err := gui.g.Suspend(); err != nil {
-		return false, gui.surfaceError(err)
+		return false, gui.c.Error(err)
 	}
 
 	gui.PauseBackgroundThreads = true
@@ -653,14 +702,14 @@ func (gui *Gui) runSubprocessWithSuspense(subprocess oscommands.ICmdObj) (bool,
 	gui.PauseBackgroundThreads = false
 
 	if cmdErr != nil {
-		return false, gui.surfaceError(cmdErr)
+		return false, gui.c.Error(cmdErr)
 	}
 
 	return true, nil
 }
 
 func (gui *Gui) runSubprocess(cmdObj oscommands.ICmdObj) error { //nolint:unparam
-	gui.logCommand(cmdObj.ToString(), true)
+	gui.LogCommand(cmdObj.ToString(), true)
 
 	subprocess := cmdObj.GetCmd()
 	subprocess.Stdout = os.Stdout
@@ -688,11 +737,11 @@ func (gui *Gui) loadNewRepo() error {
 		return err
 	}
 
-	if err := gui.refreshSidePanels(refreshOptions{mode: ASYNC}); err != nil {
+	if err := gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC}); err != nil {
 		return err
 	}
 
-	if err := gui.OSCommand.UpdateWindowTitle(); err != nil {
+	if err := gui.os.UpdateWindowTitle(); err != nil {
 		return err
 	}
 
@@ -708,7 +757,7 @@ func (gui *Gui) showInitialPopups(tasks []func(chan struct{}) error) {
 			task := task
 			go utils.Safe(func() {
 				if err := task(done); err != nil {
-					_ = gui.surfaceError(err)
+					_ = gui.c.Error(err)
 				}
 			})
 
@@ -721,15 +770,15 @@ func (gui *Gui) showInitialPopups(tasks []func(chan struct{}) error) {
 func (gui *Gui) showIntroPopupMessage(done chan struct{}) error {
 	onConfirm := func() error {
 		done <- struct{}{}
-		gui.Config.GetAppState().StartupPopupVersion = StartupPopupVersion
-		return gui.Config.SaveAppState()
+		gui.c.GetAppState().StartupPopupVersion = StartupPopupVersion
+		return gui.c.SaveAppState()
 	}
 
-	return gui.ask(askOpts{
-		title:         "",
-		prompt:        gui.Tr.IntroPopupMessage,
-		handleConfirm: onConfirm,
-		handleClose:   onConfirm,
+	return gui.c.Confirm(types.ConfirmOpts{
+		Title:         "",
+		Prompt:        gui.c.Tr.IntroPopupMessage,
+		HandleConfirm: onConfirm,
+		HandleClose:   onConfirm,
 	})
 }
 
@@ -760,10 +809,7 @@ func (gui *Gui) startBackgroundFetch() {
 	}
 	err := gui.backgroundFetch()
 	if err != nil && strings.Contains(err.Error(), "exit status 128") && isNew {
-		_ = gui.ask(askOpts{
-			title:  gui.Tr.NoAutomaticGitFetchTitle,
-			prompt: gui.Tr.NoAutomaticGitFetchBody,
-		})
+		_ = gui.c.Alert(gui.c.Tr.NoAutomaticGitFetchTitle, gui.c.Tr.NoAutomaticGitFetchBody)
 	} else {
 		gui.goEvery(time.Second*time.Duration(userConfig.Refresher.FetchInterval), gui.stopChan, func() error {
 			err := gui.backgroundFetch()
