@@ -87,9 +87,9 @@ func (gui *Gui) copySelectedToClipboard() error {
 	return gui.withLBLActiveCheck(func(state *LblPanelState) error {
 		selected := state.PlainRenderSelected()
 
-		gui.logAction(gui.Tr.Actions.CopySelectedTextToClipboard)
-		if err := gui.OSCommand.CopyToClipboard(selected); err != nil {
-			return gui.surfaceError(err)
+		gui.c.LogAction(gui.c.Tr.Actions.CopySelectedTextToClipboard)
+		if err := gui.os.CopyToClipboard(selected); err != nil {
+			return gui.c.Error(err)
 		}
 
 		return nil
@@ -106,10 +106,6 @@ func (gui *Gui) refreshAndFocusLblPanel(state *LblPanelState) error {
 
 func (gui *Gui) handleLBLMouseDown() error {
 	return gui.withLBLActiveCheck(func(state *LblPanelState) error {
-		if gui.popupPanelFocused() {
-			return nil
-		}
-
 		state.SelectNewLineForRange(gui.Views.Main.SelectedLineIdx())
 
 		return gui.refreshAndFocusLblPanel(state)
@@ -118,22 +114,12 @@ func (gui *Gui) handleLBLMouseDown() error {
 
 func (gui *Gui) handleMouseDrag() error {
 	return gui.withLBLActiveCheck(func(state *LblPanelState) error {
-		if gui.popupPanelFocused() {
-			return nil
-		}
-
 		state.SelectLine(gui.Views.Main.SelectedLineIdx())
 
 		return gui.refreshAndFocusLblPanel(state)
 	})
 }
 
-func (gui *Gui) getSelectedCommitFileName() string {
-	idx := gui.State.Panels.CommitFiles.SelectedLineIdx
-
-	return gui.State.CommitFileTreeViewModel.GetItemAtIndex(idx).GetPath()
-}
-
 func (gui *Gui) refreshMainViewForLineByLine(state *LblPanelState) error {
 	var includedLineIndices []int
 	// I'd prefer not to have knowledge of contexts using this file but I'm not sure
@@ -141,7 +127,7 @@ func (gui *Gui) refreshMainViewForLineByLine(state *LblPanelState) error {
 	if gui.currentContext().GetKey() == gui.State.Contexts.PatchBuilding.GetKey() {
 		filename := gui.getSelectedCommitFileName()
 		var err error
-		includedLineIndices, err = gui.Git.Patch.PatchManager.GetFileIncLineIndices(filename)
+		includedLineIndices, err = gui.git.Patch.PatchManager.GetFileIncLineIndices(filename)
 		if err != nil {
 			return err
 		}
@@ -215,7 +201,7 @@ func (gui *Gui) handleOpenFileAtLine() error {
 
 		// need to look at current index, then work out what my hunk's header information is, and see how far my line is away from the hunk header
 		lineNumber := state.CurrentLineNumber()
-		if err := gui.editFileAtLine(filename, lineNumber); err != nil {
+		if err := gui.os.OpenFileAtLine(filename, lineNumber); err != nil {
 			return err
 		}
 
@@ -285,5 +271,5 @@ func (gui *Gui) handleLineByLineEdit() error {
 	}
 
 	lineNumber := gui.State.Panels.LineByLine.CurrentLineNumber()
-	return gui.editFileAtLine(file.Name, lineNumber)
+	return gui.helpers.Files.EditFileAtLine(file.Name, lineNumber)
 }
