@@ -9,6 +9,7 @@ import (
 
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/gui/mergeconflicts"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
 func (gui *Gui) handleSelectPrevConflictHunk() error {
@@ -51,9 +52,9 @@ func (gui *Gui) handleMergeConflictUndo() error {
 		return nil
 	}
 
-	gui.logAction("Restoring file to previous state")
-	gui.logCommand("Undoing last conflict resolution", false)
-	if err := ioutil.WriteFile(state.GetPath(), []byte(state.GetContent()), 0644); err != nil {
+	gui.c.LogAction("Restoring file to previous state")
+	gui.LogCommand("Undoing last conflict resolution", false)
+	if err := ioutil.WriteFile(state.GetPath(), []byte(state.GetContent()), 0o644); err != nil {
 		return err
 	}
 
@@ -123,10 +124,10 @@ func (gui *Gui) resolveConflict(selection mergeconflicts.Selection) (bool, error
 	case mergeconflicts.ALL:
 		logStr = "Picking all hunks"
 	}
-	gui.logAction("Resolve merge conflict")
-	gui.logCommand(logStr, false)
+	gui.c.LogAction("Resolve merge conflict")
+	gui.LogCommand(logStr, false)
 	state.PushContent(content)
-	return true, ioutil.WriteFile(state.GetPath(), []byte(content), 0644)
+	return true, ioutil.WriteFile(state.GetPath(), []byte(content), 0o644)
 }
 
 // precondition: we actually have conflicts to render
@@ -152,9 +153,10 @@ func (gui *Gui) renderConflicts(hasFocus bool) error {
 
 	return gui.refreshMainViews(refreshMainOpts{
 		main: &viewUpdateOpts{
-			title:  gui.Tr.MergeConflictsTitle,
-			task:   NewRenderStringWithoutScrollTask(content),
-			noWrap: true,
+			title:   gui.c.Tr.MergeConflictsTitle,
+			task:    NewRenderStringWithoutScrollTask(content),
+			context: gui.State.Contexts.Merging,
+			noWrap:  true,
 		},
 	})
 }
@@ -177,19 +179,19 @@ func (gui *Gui) centerYPos(view *gocui.View, y int) {
 }
 
 func (gui *Gui) getMergingOptions() map[string]string {
-	keybindingConfig := gui.UserConfig.Keybinding
+	keybindingConfig := gui.c.UserConfig.Keybinding
 
 	return map[string]string{
-		fmt.Sprintf("%s %s", gui.getKeyDisplay(keybindingConfig.Universal.PrevItem), gui.getKeyDisplay(keybindingConfig.Universal.NextItem)):   gui.Tr.LcSelectHunk,
-		fmt.Sprintf("%s %s", gui.getKeyDisplay(keybindingConfig.Universal.PrevBlock), gui.getKeyDisplay(keybindingConfig.Universal.NextBlock)): gui.Tr.LcNavigateConflicts,
-		gui.getKeyDisplay(keybindingConfig.Universal.Select):   gui.Tr.LcPickHunk,
-		gui.getKeyDisplay(keybindingConfig.Main.PickBothHunks): gui.Tr.LcPickAllHunks,
-		gui.getKeyDisplay(keybindingConfig.Universal.Undo):     gui.Tr.LcUndo,
+		fmt.Sprintf("%s %s", gui.getKeyDisplay(keybindingConfig.Universal.PrevItem), gui.getKeyDisplay(keybindingConfig.Universal.NextItem)):   gui.c.Tr.LcSelectHunk,
+		fmt.Sprintf("%s %s", gui.getKeyDisplay(keybindingConfig.Universal.PrevBlock), gui.getKeyDisplay(keybindingConfig.Universal.NextBlock)): gui.c.Tr.LcNavigateConflicts,
+		gui.getKeyDisplay(keybindingConfig.Universal.Select):   gui.c.Tr.LcPickHunk,
+		gui.getKeyDisplay(keybindingConfig.Main.PickBothHunks): gui.c.Tr.LcPickAllHunks,
+		gui.getKeyDisplay(keybindingConfig.Universal.Undo):     gui.c.Tr.LcUndo,
 	}
 }
 
 func (gui *Gui) handleEscapeMerge() error {
-	if err := gui.refreshSidePanels(refreshOptions{scope: []RefreshableView{FILES}}); err != nil {
+	if err := gui.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}}); err != nil {
 		return err
 	}
 
@@ -199,7 +201,7 @@ func (gui *Gui) handleEscapeMerge() error {
 func (gui *Gui) onLastConflictResolved() error {
 	// as part of refreshing files, we handle the situation where a file has had
 	// its merge conflicts resolved.
-	return gui.refreshSidePanels(refreshOptions{mode: ASYNC, scope: []RefreshableView{FILES}})
+	return gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}})
 }
 
 func (gui *Gui) resetMergeState() {
@@ -208,7 +210,7 @@ func (gui *Gui) resetMergeState() {
 }
 
 func (gui *Gui) setMergeState(path string) (bool, error) {
-	content, err := gui.Git.File.Cat(path)
+	content, err := gui.git.File.Cat(path)
 	if err != nil {
 		return false, err
 	}
@@ -268,7 +270,6 @@ func (gui *Gui) setConflictsAndRender(path string, hasFocus bool) (bool, error)
 		return false, err
 	}
 
-	// if we don't have conflicts we'll fall through and show the diff
 	if hasConflicts {
 		return true, gui.renderConflicts(hasFocus)
 	}
@@ -283,22 +284,38 @@ func (gui *Gui) setConflictsAndRenderWithLock(path string, hasFocus bool) (bool,
 	return gui.setConflictsAndRender(path, hasFocus)
 }
 
-func (gui *Gui) refreshMergeState() error {
-	gui.State.Panels.Merging.Lock()
-	defer gui.State.Panels.Merging.Unlock()
+func (gui *Gui) switchToMerge(path string) error {
+	gui.takeOverMergeConflictScrolling()
 
-	if gui.currentContext().GetKey() != MAIN_MERGING_CONTEXT_KEY {
+	if gui.State.Panels.Merging.GetPath() != path {
+		hasConflicts, err := gui.setMergeStateWithLock(path)
+		if err != nil {
+			return err
+		}
+		if !hasConflicts {
+			return nil
+		}
+	}
+
+	return gui.c.PushContext(gui.State.Contexts.Merging)
+}
+
+func (gui *Gui) handleMergeConflictEditFileAtLine() error {
+	file := gui.getSelectedFile()
+	if file == nil {
 		return nil
 	}
 
-	hasConflicts, err := gui.setConflictsAndRender(gui.State.Panels.Merging.GetPath(), true)
-	if err != nil {
-		return gui.surfaceError(err)
-	}
+	lineNumber := gui.State.Panels.Merging.GetSelectedLine()
+	return gui.helpers.Files.EditFileAtLine(file.GetPath(), lineNumber)
+}
 
-	if !hasConflicts {
-		return gui.escapeMerge()
+func (gui *Gui) handleMergeConflictOpenFileAtLine() error {
+	file := gui.getSelectedFile()
+	if file == nil {
+		return nil
 	}
 
-	return nil
+	lineNumber := gui.State.Panels.Merging.GetSelectedLine()
+	return gui.helpers.Files.OpenFileAtLine(file.GetPath(), lineNumber)
 }
