@@ -1,16 +1,22 @@
 package gui
 
 import (
-	"fmt"
-
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/gui/types"
+	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
 func (gui *Gui) showUpdatePrompt(newVersion string) error {
-	return gui.ask(askOpts{
-		title:  "New version available!",
-		prompt: fmt.Sprintf("Download version %s? (enter/esc)", newVersion),
-		handleConfirm: func() error {
+	message := utils.ResolvePlaceholderString(
+		gui.Tr.UpdateAvailable, map[string]string{
+			"newVersion": newVersion,
+		},
+	)
+
+	return gui.c.Confirm(types.ConfirmOpts{
+		Title:  gui.Tr.UpdateAvailableTitle,
+		Prompt: message,
+		HandleConfirm: func() error {
 			gui.startUpdating(newVersion)
 			return nil
 		},
@@ -19,10 +25,10 @@ func (gui *Gui) showUpdatePrompt(newVersion string) error {
 
 func (gui *Gui) onUserUpdateCheckFinish(newVersion string, err error) error {
 	if err != nil {
-		return gui.surfaceError(err)
+		return gui.c.Error(err)
 	}
 	if newVersion == "" {
-		return gui.createErrorPanel("New version not found")
+		return gui.c.ErrorMsg(gui.Tr.FailedToRetrieveLatestVersionErr)
 	}
 	return gui.showUpdatePrompt(newVersion)
 }
@@ -30,13 +36,13 @@ func (gui *Gui) onUserUpdateCheckFinish(newVersion string, err error) error {
 func (gui *Gui) onBackgroundUpdateCheckFinish(newVersion string, err error) error {
 	if err != nil {
 		// ignoring the error for now so that I'm not annoying users
-		gui.Log.Error(err.Error())
+		gui.c.Log.Error(err.Error())
 		return nil
 	}
 	if newVersion == "" {
 		return nil
 	}
-	if gui.UserConfig.Update.Method == "background" {
+	if gui.c.UserConfig.Update.Method == "background" {
 		gui.startUpdating(newVersion)
 		return nil
 	}
@@ -45,7 +51,7 @@ func (gui *Gui) onBackgroundUpdateCheckFinish(newVersion string, err error) erro
 
 func (gui *Gui) startUpdating(newVersion string) {
 	gui.State.Updating = true
-	statusId := gui.statusManager.addWaitingStatus("updating")
+	statusId := gui.statusManager.addWaitingStatus(gui.Tr.UpdateInProgressWaitingStatus)
 	gui.Updater.Update(newVersion, func(err error) error { return gui.onUpdateFinish(statusId, err) })
 }
 
@@ -55,19 +61,24 @@ func (gui *Gui) onUpdateFinish(statusId int, err error) error {
 	gui.OnUIThread(func() error {
 		_ = gui.renderString(gui.Views.AppStatus, "")
 		if err != nil {
-			return gui.createErrorPanel("Update failed: " + err.Error())
+			errMessage := utils.ResolvePlaceholderString(
+				gui.Tr.UpdateFailedErr, map[string]string{
+					"errMessage": err.Error(),
+				},
+			)
+			return gui.c.ErrorMsg(errMessage)
 		}
-		return nil
+		return gui.c.Alert(gui.Tr.UpdateCompletedTitle, gui.Tr.UpdateCompleted)
 	})
 
 	return nil
 }
 
 func (gui *Gui) createUpdateQuitConfirmation() error {
-	return gui.ask(askOpts{
-		title:  "Currently Updating",
-		prompt: "An update is in progress. Are you sure you want to quit?",
-		handleConfirm: func() error {
+	return gui.c.Confirm(types.ConfirmOpts{
+		Title:  gui.Tr.ConfirmQuitDuringUpdateTitle,
+		Prompt: gui.Tr.ConfirmQuitDuringUpdate,
+		HandleConfirm: func() error {
 			return gocui.ErrQuit
 		},
 	})
