@@ -1,33 +1,38 @@
+/*
+
+本翻译文件中的词语的翻译参考了 https://github.com/progit/progit2-zh/blob/master/TRANSLATION_NOTES.asc。
+下方的术语对照表是对其的补充。
+
+Translation in this file refer to https://github.com/progit/progit2-zh/blob/master/TRANSLATION_NOTES.asc.
+Glossary below is a supplement of that documentation.
+
+Glossary 术语对照表
+
+change   更改
+fixup    修正
+reset    重置
+
+*/
+
 package i18n
 
-// 本翻译文件中的词语的翻译参考了 https://github.com/progit/progit2-zh/blob/master/TRANSLATION_NOTES.asc。
-// 下方的术语对照表是对其的补充
-
-// Translation in this file refer to https://github.com/progit/progit2-zh/blob/master/TRANSLATION_NOTES.asc.
-// Glossary below is a supplement of that documentation.
-
-// Glossary 术语对照表
-
-// change   更改
-// fixup    修正
-// reset    重置
-
 const chineseIntroPopupMessage = `
-感谢使用 lazygit！下面几点你可能会感兴趣：
+感谢使用 lazygit！你真的太棒了。下面几点你可能会感兴趣：
 
  1) 观看此视频，快速了解 lazygit 的功能：
       https://youtu.be/CPLdltN7wgE
 
- 2) 记得阅读最新的发行说明：
+ 2) 记得看看最新发行说明：
       https://github.com/jesseduffield/lazygit/releases
 
- 3) 使用 git 说明你是一位程序员！你可以和我们一起让
-    lazygit 变得更好。考虑贡献一些代码：
+ 3) 使用 git 说明你是一位程序员！你可以和我们一起让 lazygit 变得更好。
+    考虑为本项目做些贡献吧：
       https://github.com/jesseduffield/lazygit
-    也可以赞助并告诉我哪里需要改进，点右下角的捐赠按钮就好了。
-    就算给仓库点个星星也很棒！
+    你也可以直接赞助，并告诉我哪里需要改进，点右下角的捐赠按钮就好了。
+    哪怕只是给仓库点个星星也很棒！
 `
 
+// exporting this so we can use it in tests
 func chineseTranslationSet() TranslationSet {
 	return TranslationSet{
 		NotEnoughSpace:                      "没有足够的空间来渲染面板",
@@ -40,7 +45,7 @@ func chineseTranslationSet() TranslationSet {
 		StagedChanges:                       `已暂存更改`,
 		MainTitle:                           "主要",
 		StagingTitle:                        "正在暂存",
-		MergingTitle:                        "合并中",
+		MergingTitle:                        "正在合并",
 		NormalTitle:                         "正常",
 		CommitMessage:                       "提交信息",
 		CredentialsUsername:                 "用户名",
@@ -49,6 +54,7 @@ func chineseTranslationSet() TranslationSet {
 		PassUnameWrong:                      "密码 和/或 用户名错误",
 		CommitChanges:                       "提交更改",
 		AmendLastCommit:                     "修补最后一次提交",
+		AmendLastCommitTitle:                "修补最后一次提交",
 		SureToAmend:                         "您确定要修补上一次提交吗？之后您可以从提交面板更改提交消息。",
 		NoCommitToAmend:                     "没有需要提交的修补。",
 		CommitChangesWithEditor:             "提交更改（使用编辑器编辑提交信息）",
@@ -59,22 +65,21 @@ func chineseTranslationSet() TranslationSet {
 		LcToggleStaged:                      "切换暂存状态",
 		LcToggleStagedAll:                   "切换所有文件的暂存状态",
 		LcToggleTreeView:                    "切换文件树视图",
-		LcOpenMergeTool:                     "打开合并工具",
+		LcOpenMergeTool:                     "打开外部合并工具 (git mergetool)",
 		LcRefresh:                           "刷新",
 		LcPush:                              "推送",
 		LcPull:                              "拉取",
 		LcScroll:                            "滚动",
 		MergeConflictsTitle:                 "合并冲突",
 		LcCheckout:                          "检出",
-		LcCommitFileFilter:                  "过滤提交文件",
 		NoChangedFiles:                      "没有更改过文件",
 		NoFilesDisplay:                      "没有文件可显示",
 		NotAFile:                            "不是文件",
-		PullWait:                            "拉取中……",
-		PushWait:                            "推送中……",
-		FetchWait:                           "正在抓取……",
+		PullWait:                            "正在拉取…",
+		PushWait:                            "正在推送…",
+		FetchWait:                           "正在抓取…",
 		LcSoftReset:                         "软重置",
-		AlreadyCheckedOutBranch:             "您已经检出了这个分支",
+		AlreadyCheckedOutBranch:             "您已经检出至此分支",
 		SureForceCheckout:                   "您确定要强制检出吗？您将丢失所有本地更改",
 		ForceCheckoutBranch:                 "强制检出分支",
 		BranchName:                          "分支名称",
@@ -97,7 +102,6 @@ func chineseTranslationSet() TranslationSet {
 		LcClose:                             "关闭",
 		LcQuit:                              "退出",
 		LcSquashDown:                        "向下压缩",
-		LcResetToThisCommit:                 "重置为此提交",
 		LcFixupCommit:                       "修正提交（fixup）",
 		NoCommitsThisBranch:                 "该分支没有提交",
 		OnlySquashTopmostCommit:             "只能压缩最顶层的提交",
@@ -135,7 +139,6 @@ func chineseTranslationSet() TranslationSet {
 		SureApplyStashEntry:                 "您确定要应用此贮藏条目？",
 		NoTrackedStagedFilesStash:           "没有可以贮藏的已跟踪/暂存文件",
 		StashChanges:                        "贮藏更改",
-		MergeAborted:                        "合并中止",
 		OpenConfig:                          "打开配置文件",
 		EditConfig:                          "编辑配置文件",
 		ForcePush:                           "强制推送",
@@ -143,9 +146,9 @@ func chineseTranslationSet() TranslationSet {
 		ForcePushDisabled:                   "您的分支已与远程分支不同, 并且您已经禁用了强行推送",
 		UpdatesRejectedAndForcePushDisabled: "更新被拒绝，您已禁用强制推送",
 		LcCheckForUpdate:                    "检查更新",
-		CheckingForUpdates:                  "检查更新中……",
-		OnLatestVersionErr:                  "您的软件已经是最新版本",
-		MajorVersionErr:                     "新版本 ({{.newVersion}}) 与当前版本相比，具有向后兼容的更改 ({{.currentVersion}})",
+		CheckingForUpdates:                  "正在检查更新…",
+		OnLatestVersionErr:                  "已是最新版本",
+		MajorVersionErr:                     "新版本 ({{.newVersion}}) 与当前版本 ({{.currentVersion}}) 相比，具有非向后兼容的更改",
 		CouldNotFindBinaryErr:               "在 {{.url}} 处找不到任何二进制文件",
 		MergeToolTitle:                      "合并工具",
 		MergeToolPrompt:                     "确定要打开 `git mergetool` 吗?",
@@ -187,37 +190,37 @@ func chineseTranslationSet() TranslationSet {
 		MergeOptionsTitle:                   "合并选项",
 		RebaseOptionsTitle:                  "变基选项",
 		CommitMessageTitle:                  "提交讯息",
-		LocalBranchesTitle:                  "分支标签",
+		LocalBranchesTitle:                  "分支页面",
 		SearchTitle:                         "搜索",
 		TagsTitle:                           "标签页面",
 		MenuTitle:                           "菜单",
 		RemotesTitle:                        "远程页面",
-		CredentialsTitle:                    "证书",
-		RemoteBranchesTitle:                 "远程分支（在远程页面中）",
+		RemoteBranchesTitle:                 "远程分支",
 		PatchBuildingTitle:                  "构建补丁中",
 		InformationTitle:                    "信息",
 		SecondaryTitle:                      "次要",
-		ReflogCommitsTitle:                  "Reflog",
+		ReflogCommitsTitle:                  "Reflog 页面",
 		GlobalTitle:                         "全局键绑定",
 		ConflictsResolved:                   "已解决所有冲突。是否继续？",
 		RebasingTitle:                       "变基",
 		ConfirmRebase:                       "您确定要将分支 {{.checkedOutBranch}} 变基到 {{.selectedBranch}} 吗？",
 		ConfirmMerge:                        "您确定要将分支 {{.selectedBranch}} 合并到 {{.checkedOutBranch}} 吗？",
-		FwdNoUpstream:                       "无法快进没有上游的分支",
-		FwdCommitsToPush:                    "无法快进并提交推送的分支",
+		FwdNoUpstream:                       "此分支没有上游，无法快进",
+		FwdNoLocalUpstream:                  "此分支的远程未在本地注册，无法快进",
+		FwdCommitsToPush:                    "此分支带有尚未推送的提交，无法快进",
 		ErrorOccurred:                       "发生错误！请在以下位置创建 issue",
-		NoRoom:                              "没有足够的空间",
+		NoRoom:                              "空间不足",
 		YouAreHere:                          "您在这里",
 		LcRewordNotSupported:                "当前不支持交互式重新基准化时的重新措词提交",
 		LcCherryPickCopy:                    "复制提交（拣选）",
 		LcCherryPickCopyRange:               "复制提交范围（拣选）",
 		LcPasteCommits:                      "粘贴提交（拣选）",
 		SureCherryPick:                      "您确定要将选中的提交进行拣选到这个分支吗？",
-		CherryPick:                          "拣选",
-		CannotRebaseOntoFirstCommit:         "您不能以交互方式基于第一次提交",
-		CannotSquashOntoSecondCommit:        "您不能 压缩/修正(fixup)第二个提交",
+		CherryPick:                          "拣选 (Cherry-Pick)",
+		CannotRebaseOntoFirstCommit:         "您不能以交互方式变基 (rebase) 至第一次提交",
+		CannotSquashOntoSecondCommit:        "您不能压缩 (squash) 或修正 (fixup) 第二个提交",
 		Donate:                              "捐助",
-		AskQuestion:                         "问题咨询",
+		AskQuestion:                         "提问咨询",
 		PrevLine:                            "选择上一行",
 		NextLine:                            "选择下一行",
 		PrevHunk:                            "选择上一个区块",
@@ -238,26 +241,26 @@ func chineseTranslationSet() TranslationSet {
 		FixingStatus:                        "正在修正",
 		DeletingStatus:                      "正在删除",
 		MovingStatus:                        "正在移动",
-		RebasingStatus:                      "变基",
-		AmendingStatus:                      "修改",
-		CherryPickingStatus:                 "拣选中",
+		RebasingStatus:                      "正在变基",
+		AmendingStatus:                      "正在修改",
+		CherryPickingStatus:                 "正在拣选",
 		UndoingStatus:                       "正在撤销",
 		RedoingStatus:                       "正在重做",
-		CheckingOutStatus:                   "检出",
+		CheckingOutStatus:                   "长子检出",
 		CommittingStatus:                    "正在提交",
 		CommitFiles:                         "提交文件",
-		LcViewCommitFiles:                   "查看提交的文件",
+		LcViewItemFiles:                     "查看提交的文件",
 		CommitFilesTitle:                    "提交文件",
 		LcCheckoutCommitFile:                "检出文件",
 		LcDiscardOldFileChange:              "放弃对此文件的提交更改",
 		DiscardFileChangesTitle:             "放弃文件更改",
 		DiscardFileChangesPrompt:            "您确定要舍弃此提交对该文件的更改吗？如果此文件是在此提交中创建的，它将被删除",
 		DisabledForGPG:                      "该功能不适用于使用 GPG 的用户",
-		CreateRepo:                          "不在 git 仓库中。创建一个新的 git 仓库吗？(y/n): ",
+		CreateRepo:                          "当前目录不在 git 仓库中。是否在此目录创建一个新的 git 仓库？(y/n): ",
 		AutoStashTitle:                      "自动存储？",
 		AutoStashPrompt:                     "您必须隐藏并弹出更改以使更改生效。自动执行？(enter/esc)",
 		StashPrefix:                         "自动隐藏更改 ",
-		LcViewDiscardOptions:                "查看'放弃更改‘选项",
+		LcViewDiscardOptions:                "查看'放弃更改'选项",
 		LcCancel:                            "取消",
 		LcDiscardAllChanges:                 "放弃所有更改",
 		LcDiscardUnstagedChanges:            "放弃未暂存的变更",
@@ -278,12 +281,15 @@ func chineseTranslationSet() TranslationSet {
 		SkipHookPrefixNotConfigured:         "您尚未配置用于跳过钩子的提交消息前缀。请在您的配置中设置 `git.skipHookPrefix ='WIP'`",
 		LcResetTo:                           `重置为`,
 		PressEnterToReturn:                  "按下 Enter 键返回 lazygit",
-		LcViewStashOptions:                  "查看隐藏选项",
+		LcViewStashOptions:                  "查看贮藏选项",
 		LcStashAllChanges:                   "将所有更改加入贮藏",
-		LcStashStagedChanges:                "将已暂存的更改加入贮藏",
+		LcStashAllChangesKeepIndex:          "将已暂存的更改加入贮藏",
 		LcStashOptions:                      "贮藏选项",
 		NotARepository:                      "错误：必须在 git 仓库中运行",
 		LcJump:                              "跳到面板",
+		LcScrollLeftRight:                   "左右滚动",
+		LcScrollLeft:                        "向左滚动",
+		LcScrollRight:                       "向右滚动",
 		DiscardPatch:                        "丢弃补丁",
 		DiscardPatchConfirm:                 "您一次只能通过一个提交或贮藏条目构建补丁。需要放弃当前补丁吗？",
 		CantPatchWhileRebasingError:         "处于合并或变基状态时，您无法构建修补程序或运行修补程序命令",
@@ -293,11 +299,12 @@ func chineseTranslationSet() TranslationSet {
 		NoPatchError:                        "尚未创建补丁。你可以在提交中的文件上按下“空格”或使用“回车”添加其中的特定行以开始构建补丁",
 		LcEnterFile:                         "输入文件以将所选行添加到补丁中（或切换目录折叠）",
 		ExitLineByLineMode:                  `退出逐行模式`,
-		EnterUpstream:                       `以这种形式输入上游：“<远程仓库> <分支名称>”`,
+		EnterUpstream:                       `以这种格式输入上游：'<远程仓库> <分支名称>'`,
+		InvalidUpstream:                     "上游格式无效，格式应当为：'<remote> <branchname>'",
 		ReturnToRemotesList:                 `返回远程仓库列表`,
 		LcAddNewRemote:                      `添加新的远程仓库`,
-		LcNewRemoteName:                     `新的远程仓库名称:`,
-		LcNewRemoteUrl:                      `新的远程仓库 URL:`,
+		LcNewRemoteName:                     `新远程仓库名称:`,
+		LcNewRemoteUrl:                      `新远程仓库 URL:`,
 		LcEditRemoteName:                    `输入远程仓库 {{.remoteName}} 的新名称：`,
 		LcEditRemoteUrl:                     `输入远程仓库 {{.remoteName}} 的新 URL：`,
 		LcRemoveRemote:                      `删除远程`,
@@ -305,18 +312,23 @@ func chineseTranslationSet() TranslationSet {
 		DeleteRemoteBranch:                  "删除远程分支",
 		DeleteRemoteBranchMessage:           "您确定要删除远程分支吗？",
 		LcSetUpstream:                       "设置为检出分支的上游",
+		LcSetAsUpstream:                     "设置为检出分支的上游",
 		SetUpstreamTitle:                    "设置上游分支",
 		SetUpstreamMessage:                  "您确定要将 {{.checkedOut}} 的上游分支设置为 {{.selected}} 吗？",
 		LcEditRemote:                        "编辑远程仓库",
 		LcTagCommit:                         "标签提交",
-		TagNameTitle:                        "标签名：",
+		TagMenuTitle:                        "创建标签",
+		TagNameTitle:                        "标签名称：",
+		TagMessageTitle:                     "标签消息：",
+		LcAnnotatedTag:                      "附注标签",
+		LcLightweightTag:                    "轻量标签",
 		LcDeleteTag:                         "删除标签",
 		DeleteTagTitle:                      "删除标签",
 		DeleteTagPrompt:                     "您确定要删除标签 {{.tagName}} 吗？",
 		PushTagTitle:                        "将 {{.tagName}} 推送到远程仓库：",
 		LcPushTag:                           "推送标签",
 		LcCreateTag:                         "创建标签",
-		CreateTagTitle:                      "标签名：",
+		CreateTagTitle:                      "标签名称：",
 		LcFetchRemote:                       "抓取远程仓库",
 		FetchingRemoteStatus:                "抓取远程仓库中",
 		LcCheckoutCommit:                    "检出提交",
@@ -336,7 +348,6 @@ func chineseTranslationSet() TranslationSet {
 		NewBranchNamePrompt:                 "输入分支的新名称",
 		RenameBranchWarning:                 "该分支正在跟踪远程仓库。此操作将仅会重命名本地分支名称，而不会重命名远程分支的名称。确定继续？",
 		LcOpenMenu:                          "打开菜单",
-		LcCloseMenu:                         "关闭菜单",
 		LcResetCherryPick:                   "重置已拣选（复制）的提交",
 		LcNextTab:                           "下一个标签",
 		LcPrevTab:                           "上一个标签",
@@ -360,31 +371,32 @@ func chineseTranslationSet() TranslationSet {
 		MustExitFilterModeTitle:             "命令不可用",
 		MustExitFilterModePrompt:            "命令在过滤模式下不可用。退出过滤模式？",
 		LcDiff:                              "差异",
-		LcEnterRefToDiff:                    "输入 ref 以 diff", // TODO
+		LcEnterRefToDiff:                    "输入 ref 以 diff",
 		LcEnteRefName:                       "输入 ref：",
 		LcExitDiffMode:                      "退出差异模式",
-		DiffingMenuTitle:                    "diff 中", // TODO
+		DiffingMenuTitle:                    "正在 diff",
 		LcSwapDiff:                          "反向 diff",
 		LcOpenDiffingMenu:                   "打开 diff 菜单",
+		// 实际视图 (actual view) 是附加视图 (extras view)，未来,我打算为附加视图提供更多选项卡，但现在，上面的文本只需要提及“命令日志”这个部分
 		LcOpenExtrasMenu:                    "打开命令日志菜单",
-		LcShowingGitDiff:                    "显示输出：", // TODO
+		LcShowingGitDiff:                    "显示输出：",
 		LcCopyCommitShaToClipboard:          "将提交的 SHA 复制到剪贴板",
 		LcCopyCommitMessageToClipboard:      "将提交消息复制到剪贴板",
 		LcCopyBranchNameToClipboard:         "将分支名称复制到剪贴板",
 		LcCopyFileNameToClipboard:           "将文件名复制到剪贴板",
 		LcCopyCommitFileNameToClipboard:     "将提交的文件名复制到剪贴板",
+		LcCopySelectedTexToClipboard:        "将选中文本复制到剪贴板",
 		LcCommitPrefixPatternError:          "提交前缀模式错误",
 		NoFilesStagedTitle:                  "没有暂存文件",
 		NoFilesStagedPrompt:                 "您尚未暂存任何文件。提交所有文件？",
 		BranchNotFoundTitle:                 "找不到分支",
 		BranchNotFoundPrompt:                "找不到分支。创建一个新分支命名为：",
-		UnstageLinesTitle:                   "未暂存的行",
+		UnstageLinesTitle:                   "取消暂存选中的行",
 		UnstageLinesPrompt:                  "您确定要删除所选的行（git reset）吗？这是不可逆的。\n要禁用此对话框，请将 'gui.skipUnstageLineWarning' 的配置键设置为 true",
 		LcCreateNewBranchFromCommit:         "从提交创建新分支",
-		LcViewStashFiles:                    "查看贮藏条目中的文件",
 		LcBuildingPatch:                     "正在构建补丁",
 		LcViewCommits:                       "查看提交",
-		MinGitVersionError:                  "Git 版本必须至少为 2.0（即从 2014 年开始）。请升级您的 git 版本。或者在 https://github.com/jesseduffield/lazygit/issues 上提出一个问题，以使 lazygit 更加向后兼容。",
+		MinGitVersionError:                  "Git 版本必须至少为 2.0（即从 2014 年开始的版本）。请更新 git。或者在 https://github.com/jesseduffield/lazygit/issues 上提出一个问题，以使 lazygit 更加向后兼容。",
 		LcRunningCustomCommandStatus:        "正在运行自定义命令",
 		LcSubmoduleStashAndReset:            "存放未提交的子模块更改和更新",
 		LcAndResetSubmodules:                "和重置子模块",
@@ -392,14 +404,14 @@ func chineseTranslationSet() TranslationSet {
 		LcCopySubmoduleNameToClipboard:      "将子模块名称复制到剪贴板",
 		RemoveSubmodule:                     "删除子模块",
 		LcRemoveSubmodule:                   "删除子模块",
-		RemoveSubmodulePrompt:               "您确定要删除子模块 %s 及其对应的目录吗？这是不可逆的。",
+		RemoveSubmodulePrompt:               "您确定要删除子模块 '%s' 及其对应的目录吗？这是不可逆的。",
 		LcResettingSubmoduleStatus:          "正在重置子模块",
 		LcNewSubmoduleName:                  "新的子模块名称：",
 		LcNewSubmoduleUrl:                   "新的子模块 URL：",
 		LcNewSubmodulePath:                  "新的子模块路径：",
 		LcAddSubmodule:                      "添加新的子模块",
 		LcAddingSubmoduleStatus:             "添加子模块",
-		LcUpdateSubmoduleUrl:                "更新子模块 %s 的 URL",
+		LcUpdateSubmoduleUrl:                "更新子模块 '%s' 的 URL",
 		LcUpdatingSubmoduleUrlStatus:        "更新 URL 中",
 		LcEditSubmoduleUrl:                  "更新子模块 URL",
 		LcInitializingSubmoduleStatus:       "正在初始化子模块",
@@ -416,6 +428,8 @@ func chineseTranslationSet() TranslationSet {
 		SubmodulesTitle:                     "子模块",
 		NavigationTitle:                     "列表面板导航",
 		SuggestionsCheatsheetTitle:          "意见建议",
+		SuggestionsTitle:                    "意见建议 (点击 %s 以聚焦)",
+		ExtrasTitle:                         "附加",
 		PushingTagStatus:                    "推送标签",
 		PullRequestURLCopiedToClipboard:     "抓取请求网址已复制到剪贴板",
 		CommitMessageCopiedToClipboard:      "提交消息复制到剪贴板",
@@ -427,21 +441,38 @@ func chineseTranslationSet() TranslationSet {
 		ToggleShowCommandLog:                "切换 显示/隐藏 命令日志",
 		FocusCommandLog:                     "焦点命令日志",
 		CommandLogHeader:                    "您可以通过按 '%s' 隐藏或集中显示该面板，或使用 `gui.showCommandLog: false`\n将其永久隐藏在您的配置中",
-		RandomTip:                           "随机提示",
+		RandomTip:                           "随机小提示",
 		SelectParentCommitForMerge:          "选择父提交进行合并",
-		ToggleWhitespaceInDiffView:          "切换是否在差异视图中显示空白更改",
-		IgnoringWhitespaceInDiffView:        "差异视图中的空格将被忽略",
-		ShowingWhitespaceInDiffView:         "空白将显示在差异视图中",
+		ToggleWhitespaceInDiffView:          "切换是否在差异视图中显示空白字符差异",
+		IgnoringWhitespaceInDiffView:        "将会在差异视图中忽略空格字符差异",
+		ShowingWhitespaceInDiffView:         "将会在差异视图中显示空白字符差异",
+		IncreaseContextInDiffView:           "扩大差异视图中显示的上下文范围",
+		DecreaseContextInDiffView:           "缩小差异视图中显示的上下文范围",
 		CreatePullRequest:                   "创建抓取请求",
 		CreatePullRequestOptions:            "创建抓取请求选项",
 		LcCreatePullRequestOptions:          "创建抓取请求选项",
 		LcDefaultBranch:                     "默认分支",
 		LcSelectBranch:                      "选择分支",
-		ConfirmRevertCommit:                 "您确定要撤消 {{.selectedCommit}} 吗？",
+		SelectConfigFile:                    "选择配置文件",
+		NoConfigFileFoundErr:                "找不到配置文件",
+		LcLoadingFileSuggestions:            "正在加载文件建议",
+		LcLoadingCommits:                    "正在加载提交",
+		MustSpecifyOriginError:              "指定分支时，必须同时指定远程",
+		GitOutput:                           "Git 输出：",
+		GitCommandFailed:                    "Git 命令执行失败。查看命令日志了解详情 (使用 %s 打开)",
+		AbortTitle:                          "放弃 %s",
+		AbortPrompt:                         "您确定要放弃当前 %s 吗？",
+		LcOpenLogMenu:                       "打开日志菜单",
+		LogMenuTitle:                        "提交日志选项",
+		ToggleShowGitGraphAll:               "切换显示完整 git 分支图 (向 `git log` 命令传入 `--all` 选项)",
+		ShowGitGraph:                        "显示 git 分支图",
+		SortCommits:                         "提交排序",
+		CantChangeContextSizeError:          "无法在补丁构建模式下更改上下文，因为我们在发布该功能时懒得支持它。 如果你真的想要这么做，请告诉我们！",
+		LcOpenCommitInBrowser:               "在浏览器中打开提交",
+		LcViewBisectOptions:                 "查看二分查找选项",
 		Actions: Actions{
 			// TODO: combine this with the original keybinding descriptions (those are all in lowercase atm)
 			CheckoutCommit:                    "检出提交",
-			CheckoutReflogCommit:              "检出reflog提交",
 			CheckoutTag:                       "检出标签",
 			CheckoutBranch:                    "检出分支",
 			ForceCheckoutBranch:               "强制检出分支",
@@ -450,7 +481,7 @@ func chineseTranslationSet() TranslationSet {
 			RebaseBranch:                      "变基分支",
 			RenameBranch:                      "重命名分支",
 			CreateBranch:                      "建立分支",
-			CherryPick:                        "拣选提交",
+			CherryPick:                        "(拣选) 粘贴提交",
 			CheckoutFile:                      "检出文件",
 			DiscardOldFileChange:              "放弃旧文件更改",
 			SquashCommitDown:                  "向下压缩提交",
@@ -461,31 +492,33 @@ func chineseTranslationSet() TranslationSet {
 			AmendCommit:                       "修改提交",
 			RevertCommit:                      "还原提交",
 			CreateFixupCommit:                 "创建修正提交",
-			SquashAllAboveFixupCommits:        "压缩所有以上的修正提交",
-			CreateLightweightTag:              "创建轻量级标签",
+			SquashAllAboveFixupCommits:        "压缩以上所有的修正提交",
+			CreateLightweightTag:              "创建轻量标签",
+			CreateAnnotatedTag:                "创建附注标签",
 			CopyCommitMessageToClipboard:      "将提交消息复制到剪贴板",
-			MoveCommitUp:                      "向上提交",
+			MoveCommitUp:                      "上移提交",
 			MoveCommitDown:                    "下移提交",
 			CustomCommand:                     "自定义命令",
-			DiscardAllChangesInDirectory:      "放弃目录中的所有更改",
-			DiscardUnstagedChangesInDirectory: "放弃目录中未暂存的更改",
-			DiscardAllChangesInFile:           "放弃文件中的所有更改",
+			DiscardAllChangesInDirectory:      "丢弃目录中的所有更改",
+			DiscardUnstagedChangesInDirectory: "丢弃目录中未暂存的更改",
+			DiscardAllChangesInFile:           "丢弃文件中的所有更改",
 			DiscardAllUnstagedChangesInFile:   "丢弃文件中所有未暂存的更改",
 			StageFile:                         "暂存文件",
-			UnstageFile:                       "未暂存文件",
+			UnstageFile:                       "取消暂存文件",
 			UnstageAllFiles:                   "取消暂存所有文件",
 			StageAllFiles:                     "暂存所有文件",
-			IgnoreFile:                        "忽略文件",
-			Commit:                            "提交(Commit)",
+			IgnoreExcludeFile:                 "忽略文件",
+			Commit:                            "提交 (Commit)",
 			EditFile:                          "编辑文件",
-			Push:                              "推送(Push)",
-			Pull:                              "拉取(Pull)",
+			Push:                              "推送 (Push)",
+			Pull:                              "拉取 (Pull)",
 			OpenFile:                          "打开文件",
-			StashAllChanges:                   "Stash所有更改",
-			StashStagedChanges:                "Stash暂存更改",
-			GitFlowFinish:                     "Git流完成",
-			GitFlowStart:                      "Git Flow开始",
+			StashAllChanges:                   "贮藏所有更改",
+			StashStagedChanges:                "贮藏暂存的更改",
+			GitFlowFinish:                     "Git flow 结果",
+			GitFlowStart:                      "Git Flow 开始",
 			CopyToClipboard:                   "复制到剪贴板",
+			CopySelectedTextToClipboard:       "将选中文本复制到剪贴板",
 			RemovePatchFromCommit:             "从提交中删除补丁",
 			MovePatchToSelectedCommit:         "将补丁移动到选定的提交",
 			MovePatchIntoIndex:                "将补丁移到索引",
@@ -494,22 +527,21 @@ func chineseTranslationSet() TranslationSet {
 			SetBranchUpstream:                 "设置分支上游",
 			AddRemote:                         "添加远程",
 			RemoveRemote:                      "移除远程",
-			UpdateRemote:                      "远程更新",
-			ApplyPatch:                        "套用补丁",
-			Stash:                             "Stash",
+			UpdateRemote:                      "更新远程",
+			ApplyPatch:                        "应用补丁",
+			Stash:                             "贮藏 (Stash)",
 			RemoveSubmodule:                   "删除子模块",
 			ResetSubmodule:                    "重置子模块",
 			AddSubmodule:                      "添加子模块",
-			UpdateSubmoduleUrl:                "更新子模块URL",
+			UpdateSubmoduleUrl:                "更新子模块 URL",
 			InitialiseSubmodule:               "初始化子模块",
 			BulkInitialiseSubmodules:          "批量初始化子模块",
 			BulkUpdateSubmodules:              "批量更新子模块",
-			BulkStashAndResetSubmodules:       "批量存储和重置子模块",
 			BulkDeinitialiseSubmodules:        "批量取消初始化子模块",
 			UpdateSubmodule:                   "更新子模块",
 			DeleteTag:                         "删除标签",
 			PushTag:                           "推送标签",
-			NukeWorkingTree:                   "Nuke工作树",
+			NukeWorkingTree:                   "Nuke 工作树",
 			DiscardUnstagedFileChanges:        "放弃未暂存的文件更改",
 			RemoveUntrackedFiles:              "删除未跟踪的文件",
 			SoftReset:                         "软重置",
@@ -518,6 +550,26 @@ func chineseTranslationSet() TranslationSet {
 			FastForwardBranch:                 "快进分支",
 			Undo:                              "撤销",
 			Redo:                              "重做",
+			CopyPullRequestURL:                "复制拉取请求 URL",
+			OpenMergeTool:                     "打开合并工具",
+			OpenCommitInBrowser:               "在浏览器中打开提交",
+			OpenPullRequest:                   "在浏览器中打开拉取请求",
+			StartBisect:                       "开始二分查找 (Bisect)",
+			ResetBisect:                       "重置二分查找",
+			BisectSkip:                        "二分查找跳过",
+			BisectMark:                        "二分查找标记",
+		},
+		Bisect: Bisect{
+			Mark:                        "将 %s 标记为 %s",
+			MarkStart:                   "将 %s 标记为 %s (start bisect)",
+			Skip:                        "跳过 %s",
+			ResetTitle:                  "重置 'git bisect'",
+			ResetPrompt:                 "您确定要重置 'git bisect' 吗？",
+			ResetOption:                 "重置二分查找",
+			BisectMenuTitle:             "二分查找",
+			CompleteTitle:               "二分查找完成",
+			CompletePrompt:              "二分查找完成！以下提交引入了此变更：\n\n%s\n\n您现在要重置 'git bisect' 吗？",
+			CompletePromptIndeterminate: "二分查找完成！一些提交被跳过了，所以下列提交中的任何一个都可能引入了此变更：\n\n%s\n\n您现在要重置 'git bisect' 吗？",
 		},
 	}
 }
