@@ -20,6 +20,7 @@ func dutchTranslationSet() TranslationSet {
 		PassUnameWrong:                      "Wachtwoord en/of gebruikersnaam verkeerd",
 		CommitChanges:                       "commit veranderingen",
 		AmendLastCommit:                     "wijzig laatste commit",
+		AmendLastCommitTitle:                "Wijzig Laatste Commit",
 		SureToAmend:                         "Weet je zeker dat je de laatste commit wilt wijzigen? U kunt het commit-bericht wijzigen vanuit het commits-paneel.",
 		NoCommitToAmend:                     "Er is geen commits om te wijzigen.",
 		CommitChangesWithEditor:             "commit veranderingen met de git editor",
@@ -33,7 +34,6 @@ func dutchTranslationSet() TranslationSet {
 		LcPush:                              "push",
 		LcPull:                              "pull",
 		LcScroll:                            "scroll",
-		LcCommitFileFilter:                  "Commit dossiers filteren",
 		FilterStagedFiles:                   "Show only staged files",
 		FilterUnstagedFiles:                 "Show only unstaged files",
 		ResetCommitFilterState:              "Reset commit file state filter",
@@ -68,7 +68,6 @@ func dutchTranslationSet() TranslationSet {
 		LcClose:                             "sluiten",
 		LcQuit:                              "quit",
 		LcSquashDown:                        "squash beneden",
-		LcResetToThisCommit:                 "reset naar deze commit",
 		LcFixupCommit:                       "Fixup commit",
 		OnlySquashTopmostCommit:             "Kan alleen bovenste commit squashen",
 		YouNoCommitsToSquash:                "Je hebt geen commits om mee te squashen",
@@ -107,7 +106,6 @@ func dutchTranslationSet() TranslationSet {
 		NoTrackedStagedFilesStash:           "Je hebt geen tracked/staged bestanden om te laten stashen",
 		StashChanges:                        "Stash veranderingen",
 		NoChangedFiles:                      "Geen veranderde bestanden",
-		MergeAborted:                        "Merge afgebroken",
 		OpenConfig:                          "open config bestand",
 		EditConfig:                          "verander config bestand",
 		ForcePush:                           "Forceer push",
@@ -157,17 +155,16 @@ func dutchTranslationSet() TranslationSet {
 		MergeOptionsTitle:                   "Merge Opties",
 		RebaseOptionsTitle:                  "Rebase Opties",
 		CommitMessageTitle:                  "Commit Bericht",
-		LocalBranchesTitle:                  "Branches Tabblad",
+		LocalBranchesTitle:                  "Branches",
 		SearchTitle:                         "Zoek",
-		TagsTitle:                           "Tags Tabblad",
+		TagsTitle:                           "Tags",
 		MenuTitle:                           "Menu",
-		RemotesTitle:                        "Remotes Tabblad",
-		CredentialsTitle:                    "Credentials",
-		RemoteBranchesTitle:                 "Remote Branches (in Remotes tabblad)",
+		RemotesTitle:                        "Remotes",
+		RemoteBranchesTitle:                 "Remote Branches",
 		PatchBuildingTitle:                  "Patch Bouwen",
 		InformationTitle:                    "Informatie",
 		SecondaryTitle:                      "Secondary",
-		ReflogCommitsTitle:                  "Reflog Tabblad",
+		ReflogCommitsTitle:                  "Reflog",
 		GlobalTitle:                         "Globale Sneltoetsen",
 		ConflictsResolved:                   "alle merge conflicten zijn opgelost. Wilt je verder gaan?",
 		RebasingTitle:                       "Rebasen",
@@ -215,7 +212,7 @@ func dutchTranslationSet() TranslationSet {
 		RedoingStatus:                       "redoing",
 		CheckingOutStatus:                   "uitchecken",
 		CommitFiles:                         "Commit bestanden",
-		LcViewCommitFiles:                   "bekijk gecommite bestanden",
+		LcViewItemFiles:                     "bekijk gecommite bestanden",
 		CommitFilesTitle:                    "Commit bestanden",
 		LcCheckoutCommitFile:                "bestand uitchecken",
 		LcDiscardOldFileChange:              "uitsluit deze commit zijn veranderingen aan dit bestand",
@@ -249,7 +246,7 @@ func dutchTranslationSet() TranslationSet {
 		PressEnterToReturn:                  "Press om terug te gaan naar lazygit",
 		LcViewStashOptions:                  "bekijk stash opties",
 		LcStashAllChanges:                   "stash-bestanden",
-		LcStashStagedChanges:                "stash staged wijzigingen",
+		LcStashAllChangesKeepIndex:          "stash staged wijzigingen",
 		LcStashOptions:                      "Stash opties",
 		NotARepository:                      "Fout: moet in een git repository uitgevoerd worden",
 		LcJump:                              "ga naar paneel",
@@ -274,6 +271,7 @@ func dutchTranslationSet() TranslationSet {
 		DeleteRemoteBranch:                  "Verwijder Remote Branch",
 		DeleteRemoteBranchMessage:           "Weet je zeker dat je deze remote branch wilt verwijderen",
 		LcSetUpstream:                       "stel in als upstream van uitgecheckte branch",
+		LcSetAsUpstream:                     "stel in als upstream van uitgecheckte branch",
 		SetUpstreamTitle:                    "Stel in als upstream branch",
 		SetUpstreamMessage:                  "Weet je zeker dat je de upstream branch van '{{.checkedOut}}' naar '{{.selected}}' wilt zetten",
 		LcEditRemote:                        "wijzig remote",
@@ -305,7 +303,6 @@ func dutchTranslationSet() TranslationSet {
 		NewBranchNamePrompt:                 "Noem een nieuwe branch naam",
 		RenameBranchWarning:                 "Deze branch volgt een remote. Deze actie zal alleen de locale branch name wijzigen niet de naam van de remote branch. Verder gaan?",
 		LcOpenMenu:                          "open menu",
-		LcCloseMenu:                         "sluit menu",
 		LcResetCherryPick:                   "reset cherry-picked (gekopieerde) commits selectie",
 		LcNextTab:                           "volgende tabblad",
 		LcPrevTab:                           "vorige tabblad",
@@ -358,7 +355,6 @@ func dutchTranslationSet() TranslationSet {
 		LcAddSubmodule:                      "voeg nieuwe submodule toe",
 		LcInitSubmodule:                     "initialiseer submodule",
 		LcViewBulkSubmoduleOptions:          "bekijk bulk submodule opties",
-		LcViewStashFiles:                    "bekijk bestanden van stash entry",
 		CreatePullRequestOptions:            "Bekijk opties voor pull-aanvraag",
 		LcCreatePullRequestOptions:          "bekijk opties voor pull-aanvraag",
 		ConfirmRevertCommit:                 "Weet u zeker dat u {{.selectedCommit}} ongedaan wilt maken?",
