@@ -22,7 +22,9 @@ type TranslationSet struct {
 	MainTitle                           string
 	StagingTitle                        string
 	MergingTitle                        string
+	MergeConfirmTitle                   string
 	NormalTitle                         string
+	LogTitle                            string
 	CommitMessage                       string
 	CredentialsUsername                 string
 	CredentialsPassword                 string
@@ -30,6 +32,7 @@ type TranslationSet struct {
 	PassUnameWrong                      string
 	CommitChanges                       string
 	AmendLastCommit                     string
+	AmendLastCommitTitle                string
 	SureToAmend                         string
 	NoCommitToAmend                     string
 	CommitChangesWithEditor             string
@@ -46,7 +49,7 @@ type TranslationSet struct {
 	LcPush                              string
 	LcPull                              string
 	LcScroll                            string
-	LcCommitFileFilter                  string
+	LcFileFilter                        string
 	FilterStagedFiles                   string
 	FilterUnstagedFiles                 string
 	ResetCommitFilterState              string
@@ -82,7 +85,6 @@ type TranslationSet struct {
 	LcClose                             string
 	LcQuit                              string
 	LcSquashDown                        string
-	LcResetToThisCommit                 string
 	LcFixupCommit                       string
 	OnlySquashTopmostCommit             string
 	YouNoCommitsToSquash                string
@@ -98,6 +100,9 @@ type TranslationSet struct {
 	LcMoveUpCommit                      string
 	LcEditCommit                        string
 	LcAmendToCommit                     string
+	LcResetCommitAuthor                 string
+	SetAuthorPromptTitle                string
+	SureResetCommitAuthor               string
 	LcRenameCommitEditor                string
 	NoCommitsThisBranch                 string
 	Error                               string
@@ -108,6 +113,8 @@ type TranslationSet struct {
 	LcUndo                              string
 	LcUndoReflog                        string
 	LcRedoReflog                        string
+	UndoTooltip                         string
+	RedoTooltip                         string
 	LcPop                               string
 	LcDrop                              string
 	LcApply                             string
@@ -119,8 +126,8 @@ type TranslationSet struct {
 	StashApply                          string
 	SureApplyStashEntry                 string
 	NoTrackedStagedFilesStash           string
+	NoFilesToStash                      string
 	StashChanges                        string
-	MergeAborted                        string
 	OpenConfig                          string
 	EditConfig                          string
 	ForcePush                           string
@@ -129,9 +136,18 @@ type TranslationSet struct {
 	UpdatesRejectedAndForcePushDisabled string
 	LcCheckForUpdate                    string
 	CheckingForUpdates                  string
+	UpdateAvailableTitle                string
+	UpdateAvailable                     string
+	UpdateInProgressWaitingStatus       string
+	UpdateCompletedTitle                string
+	UpdateCompleted                     string
+	FailedToRetrieveLatestVersionErr    string
 	OnLatestVersionErr                  string
 	MajorVersionErr                     string
 	CouldNotFindBinaryErr               string
+	UpdateFailedErr                     string
+	ConfirmQuitDuringUpdateTitle        string
+	ConfirmQuitDuringUpdate             string
 	MergeToolTitle                      string
 	MergeToolPrompt                     string
 	IntroPopupMessage                   string
@@ -139,6 +155,7 @@ type TranslationSet struct {
 	LcEditFile                          string
 	LcOpenFile                          string
 	LcIgnoreFile                        string
+	LcExcludeFile                       string
 	LcRefreshFiles                      string
 	LcMergeIntoCurrentBranch            string
 	ConfirmQuit                         string
@@ -158,6 +175,7 @@ type TranslationSet struct {
 	ToggleDragSelect                    string
 	ToggleSelectHunk                    string
 	ToggleSelectionForPatch             string
+	EditHunk                            string
 	TogglePanel                         string
 	ReturnToFilesPanel                  string
 	FastForward                         string
@@ -177,7 +195,6 @@ type TranslationSet struct {
 	TagsTitle                           string
 	MenuTitle                           string
 	RemotesTitle                        string
-	CredentialsTitle                    string
 	RemoteBranchesTitle                 string
 	PatchBuildingTitle                  string
 	InformationTitle                    string
@@ -231,7 +248,10 @@ type TranslationSet struct {
 	CheckingOutStatus                   string
 	CommittingStatus                    string
 	CommitFiles                         string
-	LcViewCommitFiles                   string
+	SubCommitsDynamicTitle              string
+	CommitFilesDynamicTitle             string
+	RemoteBranchesDynamicTitle          string
+	LcViewItemFiles                     string
 	CommitFilesTitle                    string
 	LcCheckoutCommitFile                string
 	LcDiscardOldFileChange              string
@@ -239,6 +259,8 @@ type TranslationSet struct {
 	DiscardFileChangesPrompt            string
 	DisabledForGPG                      string
 	CreateRepo                          string
+	InitialBranch                       string
+	NoRecentRepositories                string
 	AutoStashTitle                      string
 	AutoStashPrompt                     string
 	StashPrefix                         string
@@ -249,6 +271,7 @@ type TranslationSet struct {
 	LcDiscardAllChangesToAllFiles       string
 	LcDiscardAnyUnstagedChanges         string
 	LcDiscardUntrackedFiles             string
+	LcDiscardStagedChanges              string
 	LcHardReset                         string
 	LcViewResetOptions                  string
 	LcCreateFixupCommit                 string
@@ -266,6 +289,8 @@ type TranslationSet struct {
 	LcViewStashOptions                  string
 	LcStashAllChanges                   string
 	LcStashStagedChanges                string
+	LcStashAllChangesKeepIndex          string
+	LcStashUnstagedChanges              string
 	LcStashOptions                      string
 	NotARepository                      string
 	LcJump                              string
@@ -276,6 +301,8 @@ type TranslationSet struct {
 	DiscardPatchConfirm                 string
 	CantPatchWhileRebasingError         string
 	LcToggleAddToPatch                  string
+	LcToggleAllInPatch                  string
+	LcUpdatingPatch                     string
 	ViewPatchOptions                    string
 	PatchOptionsTitle                   string
 	NoPatchError                        string
@@ -293,7 +320,9 @@ type TranslationSet struct {
 	LcRemoveRemotePrompt                string
 	DeleteRemoteBranch                  string
 	DeleteRemoteBranchMessage           string
+	LcSetAsUpstream                     string
 	LcSetUpstream                       string
+	LcUnsetUpstream                     string
 	SetUpstreamTitle                    string
 	SetUpstreamMessage                  string
 	LcEditRemote                        string
@@ -318,7 +347,9 @@ type TranslationSet struct {
 	NotAGitFlowBranch                   string
 	NewBranchNamePrompt                 string
 	IgnoreTracked                       string
+	ExcludeTracked                      string
 	IgnoreTrackedPrompt                 string
+	ExcludeTrackedPrompt                string
 	LcViewResetToUpstreamOptions        string
 	LcNextScreenMode                    string
 	LcPrevScreenMode                    string
@@ -326,10 +357,10 @@ type TranslationSet struct {
 	Panel                               string
 	Keybindings                         string
 	LcRenameBranch                      string
+	LcSetUnsetUpstream                  string
 	NewGitFlowBranchPrompt              string
 	RenameBranchWarning                 string
 	LcOpenMenu                          string
-	LcCloseMenu                         string
 	LcResetCherryPick                   string
 	LcNextTab                           string
 	LcPrevTab                           string
@@ -361,8 +392,14 @@ type TranslationSet struct {
 	LcOpenDiffingMenu                   string
 	LcOpenExtrasMenu                    string
 	LcShowingGitDiff                    string
+	LcCommitDiff                        string
 	LcCopyCommitShaToClipboard          string
+	LcCommitSha                         string
+	LcCommitURL                         string
 	LcCopyCommitMessageToClipboard      string
+	LcCommitMessage                     string
+	LcCommitAuthor                      string
+	LcCopyCommitAttributeToClipboard    string
 	LcCopyBranchNameToClipboard         string
 	LcCopyFileNameToClipboard           string
 	LcCopyCommitFileNameToClipboard     string
@@ -375,7 +412,6 @@ type TranslationSet struct {
 	UnstageLinesTitle                   string
 	UnstageLinesPrompt                  string
 	LcCreateNewBranchFromCommit         string
-	LcViewStashFiles                    string
 	LcBuildingPatch                     string
 	LcViewCommits                       string
 	MinGitVersionError                  string
@@ -415,7 +451,11 @@ type TranslationSet struct {
 	ExtrasTitle                         string
 	PushingTagStatus                    string
 	PullRequestURLCopiedToClipboard     string
+	CommitDiffCopiedToClipboard         string
+	CommitSHACopiedToClipboard          string
+	CommitURLCopiedToClipboard          string
 	CommitMessageCopiedToClipboard      string
+	CommitAuthorCopiedToClipboard       string
 	LcCopiedToClipboard                 string
 	ErrCannotEditDirectory              string
 	ErrStageDirWithInlineMergeConflicts string
@@ -454,6 +494,13 @@ type TranslationSet struct {
 	LcOpenCommitInBrowser               string
 	LcViewBisectOptions                 string
 	ConfirmRevertCommit                 string
+	RewordInEditorTitle                 string
+	RewordInEditorPrompt                string
+	CheckoutPrompt                      string
+	HardResetAutostashPrompt            string
+	UpstreamGone                        string
+	NukeDescription                     string
+	DiscardStagedChangesDescription     string
 	Actions                             Actions
 	Bisect                              Bisect
 }
@@ -475,7 +522,6 @@ type Bisect struct {
 
 type Actions struct {
 	CheckoutCommit                    string
-	CheckoutReflogCommit              string
 	CheckoutTag                       string
 	CheckoutBranch                    string
 	ForceCheckoutBranch               string
@@ -483,6 +529,7 @@ type Actions struct {
 	Merge                             string
 	RebaseBranch                      string
 	RenameBranch                      string
+	SetUnsetUpstream                  string
 	CreateBranch                      string
 	FastForwardBranch                 string
 	CherryPick                        string
@@ -494,12 +541,19 @@ type Actions struct {
 	DropCommit                        string
 	EditCommit                        string
 	AmendCommit                       string
+	ResetCommitAuthor                 string
+	SetCommitAuthor                   string
 	RevertCommit                      string
 	CreateFixupCommit                 string
 	SquashAllAboveFixupCommits        string
 	MoveCommitUp                      string
 	MoveCommitDown                    string
 	CopyCommitMessageToClipboard      string
+	CopyCommitDiffToClipboard         string
+	CopyCommitSHAToClipboard          string
+	CopyCommitURLToClipboard          string
+	CopyCommitAuthorToClipboard       string
+	CopyCommitAttributeToClipboard    string
 	CustomCommand                     string
 	DiscardAllChangesInDirectory      string
 	DiscardUnstagedChangesInDirectory string
@@ -510,14 +564,21 @@ type Actions struct {
 	UnstageFile                       string
 	UnstageAllFiles                   string
 	StageAllFiles                     string
+	IgnoreExcludeFile                 string
 	IgnoreFile                        string
+	IgnoreFileErr                     string
+	ExcludeFile                       string
+	ExcludeFileErr                    string
+	ExcludeGitIgnoreErr               string
 	Commit                            string
 	EditFile                          string
 	Push                              string
 	Pull                              string
 	OpenFile                          string
 	StashAllChanges                   string
+	StashAllChangesKeepIndex          string
 	StashStagedChanges                string
+	StashUnstagedChanges              string
 	GitFlowFinish                     string
 	GitFlowStart                      string
 	CopyToClipboard                   string
@@ -540,7 +601,6 @@ type Actions struct {
 	InitialiseSubmodule               string
 	BulkInitialiseSubmodules          string
 	BulkUpdateSubmodules              string
-	BulkStashAndResetSubmodules       string
 	BulkDeinitialiseSubmodules        string
 	UpdateSubmodule                   string
 	CreateLightweightTag              string
@@ -550,6 +610,7 @@ type Actions struct {
 	NukeWorkingTree                   string
 	DiscardUnstagedFileChanges        string
 	RemoveUntrackedFiles              string
+	RemoveStagedFiles                 string
 	SoftReset                         string
 	MixedReset                        string
 	HardReset                         string
@@ -594,9 +655,11 @@ func EnglishTranslationSet() TranslationSet {
 		UnstagedChanges:                     `Unstaged Changes`,
 		StagedChanges:                       `Staged Changes`,
 		MainTitle:                           "Main",
-		StagingTitle:                        "Staging",
-		MergingTitle:                        "Merging",
-		NormalTitle:                         "Normal",
+		MergeConfirmTitle:                   "Merge",
+		StagingTitle:                        "Main Panel (Staging)",
+		MergingTitle:                        "Main Panel (Merging)",
+		NormalTitle:                         "Main Panel (Normal)",
+		LogTitle:                            "Log",
 		CommitMessage:                       "Commit message",
 		CredentialsUsername:                 "Username",
 		CredentialsPassword:                 "Password",
@@ -604,6 +667,7 @@ func EnglishTranslationSet() TranslationSet {
 		PassUnameWrong:                      "Password, passphrase and/or username wrong",
 		CommitChanges:                       "commit changes",
 		AmendLastCommit:                     "amend last commit",
+		AmendLastCommitTitle:                "Amend Last Commit",
 		SureToAmend:                         "Are you sure you want to amend last commit? Afterwards, you can change commit message from the commits panel.",
 		NoCommitToAmend:                     "There's no commit to amend.",
 		CommitChangesWithEditor:             "commit changes using git editor",
@@ -621,7 +685,7 @@ func EnglishTranslationSet() TranslationSet {
 		LcScroll:                            "scroll",
 		MergeConflictsTitle:                 "Merge Conflicts",
 		LcCheckout:                          "checkout",
-		LcCommitFileFilter:                  "Filter commit files",
+		LcFileFilter:                        "Filter files (staged/unstaged)",
 		FilterStagedFiles:                   "Show only staged files",
 		FilterUnstagedFiles:                 "Show only unstaged files",
 		ResetCommitFilterState:              "Reset filter",
@@ -651,11 +715,10 @@ func EnglishTranslationSet() TranslationSet {
 		NoBranchesThisRepo:                  "No branches for this repo",
 		CommitMessageConfirm:                "{{.keyBindClose}}: close, {{.keyBindNewLine}}: new line, {{.keyBindConfirm}}: confirm",
 		CommitWithoutMessageErr:             "You cannot commit without a commit message",
-		CloseConfirm:                        "{{.keyBindClose}}: close, {{.keyBindConfirm}}: confirm",
+		CloseConfirm:                        "{{.keyBindClose}}: close/cancel, {{.keyBindConfirm}}: confirm",
 		LcClose:                             "close",
 		LcQuit:                              "quit",
 		LcSquashDown:                        "squash down",
-		LcResetToThisCommit:                 "reset to this commit",
 		LcFixupCommit:                       "fixup commit",
 		NoCommitsThisBranch:                 "No commits for this branch",
 		OnlySquashTopmostCommit:             "Can only squash topmost commit",
@@ -672,6 +735,9 @@ func EnglishTranslationSet() TranslationSet {
 		LcMoveUpCommit:                      "move commit up one",
 		LcEditCommit:                        "edit commit",
 		LcAmendToCommit:                     "amend commit with staged changes",
+		LcResetCommitAuthor:                 "reset commit author",
+		SetAuthorPromptTitle:                "Set author (must look like 'Name <Email>')",
+		SureResetCommitAuthor:               "The author field of this commit will be updated to match the configured user. This also renews the author timestamp. Continue?",
 		LcRenameCommitEditor:                "reword commit with editor",
 		Error:                               "Error",
 		LcSelectHunk:                        "select hunk",
@@ -681,6 +747,8 @@ func EnglishTranslationSet() TranslationSet {
 		LcUndo:                              "undo",
 		LcUndoReflog:                        "undo (via reflog) (experimental)",
 		LcRedoReflog:                        "redo (via reflog) (experimental)",
+		UndoTooltip:                         "The reflog will be used to determine what git command to run to undo the last git command. This does not include changes to the working tree; only commits are taken into consideration.",
+		RedoTooltip:                         "The reflog will be used to determine what git command to run to redo the last git command. This does not include changes to the working tree; only commits are taken into consideration.",
 		LcPop:                               "pop",
 		LcDrop:                              "drop",
 		LcApply:                             "apply",
@@ -692,8 +760,8 @@ func EnglishTranslationSet() TranslationSet {
 		StashApply:                          "Stash apply",
 		SureApplyStashEntry:                 "Are you sure you want to apply this stash entry?",
 		NoTrackedStagedFilesStash:           "You have no tracked/staged files to stash",
+		NoFilesToStash:                      "You have no files to stash",
 		StashChanges:                        "Stash changes",
-		MergeAborted:                        "Merge aborted",
 		OpenConfig:                          "open config file",
 		EditConfig:                          "edit config file",
 		ForcePush:                           "Force push",
@@ -702,9 +770,18 @@ func EnglishTranslationSet() TranslationSet {
 		UpdatesRejectedAndForcePushDisabled: "Updates were rejected and you have disabled force pushing",
 		LcCheckForUpdate:                    "check for update",
 		CheckingForUpdates:                  "Checking for updates...",
+		UpdateAvailableTitle:                "Update available!",
+		UpdateAvailable:                     "Download and install version {{.newVersion}}?",
+		UpdateInProgressWaitingStatus:       "updating",
+		UpdateCompletedTitle:                "Update completed!",
+		UpdateCompleted:                     "Update has been installed successfully. Restart lazygit for it to take effect.",
+		FailedToRetrieveLatestVersionErr:    "Failed to retrieve version information",
 		OnLatestVersionErr:                  "You already have the latest version",
 		MajorVersionErr:                     "New version ({{.newVersion}}) has non-backwards compatible changes compared to the current version ({{.currentVersion}})",
 		CouldNotFindBinaryErr:               "Could not find any binary at {{.url}}",
+		UpdateFailedErr:                     "Update failed: {{.errMessage}}",
+		ConfirmQuitDuringUpdateTitle:        "Currently Updating",
+		ConfirmQuitDuringUpdate:             "An update is in progress. Are you sure you want to quit?",
 		MergeToolTitle:                      "Merge tool",
 		MergeToolPrompt:                     "Are you sure you want to open `git mergetool`?",
 		IntroPopupMessage:                   englishIntroPopupMessage,
@@ -712,6 +789,7 @@ func EnglishTranslationSet() TranslationSet {
 		LcEditFile:                          `edit file`,
 		LcOpenFile:                          `open file`,
 		LcIgnoreFile:                        `add to .gitignore`,
+		LcExcludeFile:                       `add to .git/info/exclude`,
 		LcRefreshFiles:                      `refresh files`,
 		LcMergeIntoCurrentBranch:            `merge into currently checked out branch`,
 		ConfirmQuit:                         `Are you sure you want to quit?`,
@@ -731,6 +809,7 @@ func EnglishTranslationSet() TranslationSet {
 		ToggleDragSelect:                    `toggle drag select`,
 		ToggleSelectHunk:                    `toggle select hunk`,
 		ToggleSelectionForPatch:             `add/remove line(s) to patch`,
+		EditHunk:                            `edit hunk`,
 		TogglePanel:                         `switch to other panel`,
 		ReturnToFilesPanel:                  `return to files panel`,
 		FastForward:                         `fast-forward this branch from its upstream`,
@@ -745,17 +824,16 @@ func EnglishTranslationSet() TranslationSet {
 		MergeOptionsTitle:                   "Merge Options",
 		RebaseOptionsTitle:                  "Rebase Options",
 		CommitMessageTitle:                  "Commit Message",
-		LocalBranchesTitle:                  "Branches Tab",
+		LocalBranchesTitle:                  "Local Branches",
 		SearchTitle:                         "Search",
-		TagsTitle:                           "Tags Tab",
+		TagsTitle:                           "Tags",
 		MenuTitle:                           "Menu",
-		RemotesTitle:                        "Remotes Tab",
-		CredentialsTitle:                    "Credentials",
-		RemoteBranchesTitle:                 "Remote Branches (in Remotes tab)",
-		PatchBuildingTitle:                  "Patch Building",
+		RemotesTitle:                        "Remotes",
+		RemoteBranchesTitle:                 "Remote Branches",
+		PatchBuildingTitle:                  "Main Panel (Patch Building)",
 		InformationTitle:                    "Information",
 		SecondaryTitle:                      "Secondary",
-		ReflogCommitsTitle:                  "Reflog Tab",
+		ReflogCommitsTitle:                  "Reflog",
 		GlobalTitle:                         "Global Keybindings",
 		ConflictsResolved:                   "all merge conflicts resolved. Continue?",
 		RebasingTitle:                       "Rebasing",
@@ -805,7 +883,10 @@ func EnglishTranslationSet() TranslationSet {
 		CheckingOutStatus:                   "checking out",
 		CommittingStatus:                    "committing",
 		CommitFiles:                         "Commit files",
-		LcViewCommitFiles:                   "view commit's files",
+		SubCommitsDynamicTitle:              "Commits (%s)",
+		CommitFilesDynamicTitle:             "Diff files (%s)",
+		RemoteBranchesDynamicTitle:          "Remote branches (%s)",
+		LcViewItemFiles:                     "view selected item's files",
 		CommitFilesTitle:                    "Commit Files",
 		LcCheckoutCommitFile:                "checkout file",
 		LcDiscardOldFileChange:              "discard this commit's changes to this file",
@@ -813,6 +894,8 @@ func EnglishTranslationSet() TranslationSet {
 		DiscardFileChangesPrompt:            "Are you sure you want to discard this commit's changes to this file? If this file was created in this commit, it will be deleted",
 		DisabledForGPG:                      "Feature not available for users using GPG",
 		CreateRepo:                          "Not in a git repository. Create a new git repository? (y/n): ",
+		InitialBranch:                       "Branch name? (leave empty for git's default): ",
+		NoRecentRepositories:                "Must open lazygit in a git repository. No valid recent repositories. Exiting.",
 		AutoStashTitle:                      "Autostash?",
 		AutoStashPrompt:                     "You must stash and pop your changes to bring them across. Do this automatically? (enter/esc)",
 		StashPrefix:                         "Auto-stashing changes for ",
@@ -823,6 +906,7 @@ func EnglishTranslationSet() TranslationSet {
 		LcDiscardAllChangesToAllFiles:       "nuke working tree",
 		LcDiscardAnyUnstagedChanges:         "discard unstaged changes",
 		LcDiscardUntrackedFiles:             "discard untracked files",
+		LcDiscardStagedChanges:              "discard staged changes",
 		LcHardReset:                         "hard reset",
 		LcViewResetOptions:                  `view reset options`,
 		LcCreateFixupCommit:                 `create fixup commit for this commit`,
@@ -838,8 +922,10 @@ func EnglishTranslationSet() TranslationSet {
 		LcResetTo:                           `reset to`,
 		PressEnterToReturn:                  "Press enter to return to lazygit",
 		LcViewStashOptions:                  "view stash options",
-		LcStashAllChanges:                   "stash changes",
+		LcStashAllChanges:                   "stash all changes",
 		LcStashStagedChanges:                "stash staged changes",
+		LcStashAllChangesKeepIndex:          "stash all changes and keep index",
+		LcStashUnstagedChanges:              "stash unstaged changes",
 		LcStashOptions:                      "Stash options",
 		NotARepository:                      "Error: must be run inside a git repository",
 		LcJump:                              "jump to panel",
@@ -850,6 +936,8 @@ func EnglishTranslationSet() TranslationSet {
 		DiscardPatchConfirm:                 "You can only build a patch from one commit/stash-entry at a time. Discard current patch?",
 		CantPatchWhileRebasingError:         "You cannot build a patch or run patch commands while in a merging or rebasing state",
 		LcToggleAddToPatch:                  "toggle file included in patch",
+		LcToggleAllInPatch:                  "toggle all files included in patch",
+		LcUpdatingPatch:                     "updating patch",
 		ViewPatchOptions:                    "view custom patch options",
 		PatchOptionsTitle:                   "Patch Options",
 		NoPatchError:                        "No patch created yet. To start building a patch, use 'space' on a commit file or enter to add specific lines",
@@ -867,7 +955,9 @@ func EnglishTranslationSet() TranslationSet {
 		LcRemoveRemotePrompt:                "Are you sure you want to remove remote",
 		DeleteRemoteBranch:                  "Delete Remote Branch",
 		DeleteRemoteBranchMessage:           "Are you sure you want to delete remote branch",
-		LcSetUpstream:                       "set as upstream of checked-out branch",
+		LcSetAsUpstream:                     "set as upstream of checked-out branch",
+		LcSetUpstream:                       "set upstream of selected branch",
+		LcUnsetUpstream:                     "unset upstream of selected branch",
 		SetUpstreamTitle:                    "Set upstream branch",
 		SetUpstreamMessage:                  "Are you sure you want to set the upstream branch of '{{.checkedOut}}' to '{{.selected}}'",
 		LcEditRemote:                        "edit remote",
@@ -893,6 +983,8 @@ func EnglishTranslationSet() TranslationSet {
 		NewGitFlowBranchPrompt:              "new {{.branchType}} name:",
 		IgnoreTracked:                       "Ignore tracked file",
 		IgnoreTrackedPrompt:                 "Are you sure you want to ignore a tracked file?",
+		ExcludeTracked:                      "Exclude tracked file",
+		ExcludeTrackedPrompt:                "Are you sure you want to exclude a tracked file?",
 		LcViewResetToUpstreamOptions:        "view upstream reset options",
 		LcNextScreenMode:                    "next screen mode (normal/half/fullscreen)",
 		LcPrevScreenMode:                    "prev screen mode",
@@ -900,10 +992,10 @@ func EnglishTranslationSet() TranslationSet {
 		Panel:                               "Panel",
 		Keybindings:                         "Keybindings",
 		LcRenameBranch:                      "rename branch",
+		LcSetUnsetUpstream:                  "set/unset upstream",
 		NewBranchNamePrompt:                 "Enter new branch name for branch",
 		RenameBranchWarning:                 "This branch is tracking a remote. This action will only rename the local branch name, not the name of the remote branch. Continue?",
 		LcOpenMenu:                          "open menu",
-		LcCloseMenu:                         "close menu",
 		LcResetCherryPick:                   "reset cherry-picked (copied) commits selection",
 		LcNextTab:                           "next tab",
 		LcPrevTab:                           "previous tab",
@@ -936,8 +1028,14 @@ func EnglishTranslationSet() TranslationSet {
 		// the actual view is the extras view which I intend to give more tabs in future but for now we'll only mention the command log part
 		LcOpenExtrasMenu:                    "open command log menu",
 		LcShowingGitDiff:                    "showing output for:",
+		LcCommitDiff:                        "commit diff",
 		LcCopyCommitShaToClipboard:          "copy commit SHA to clipboard",
+		LcCommitSha:                         "commit SHA",
+		LcCommitURL:                         "commit URL",
 		LcCopyCommitMessageToClipboard:      "copy commit message to clipboard",
+		LcCommitMessage:                     "commit message",
+		LcCommitAuthor:                      "commit author",
+		LcCopyCommitAttributeToClipboard:    "copy commit attribute",
 		LcCopyBranchNameToClipboard:         "copy branch name to clipboard",
 		LcCopyFileNameToClipboard:           "copy the file name to the clipboard",
 		LcCopyCommitFileNameToClipboard:     "copy the committed file name to the clipboard",
@@ -950,7 +1048,6 @@ func EnglishTranslationSet() TranslationSet {
 		UnstageLinesTitle:                   "Unstage lines",
 		UnstageLinesPrompt:                  "Are you sure you want to delete the selected lines (git reset)? It is irreversible.\nTo disable this dialogue set the config key of 'gui.skipUnstageLineWarning' to true",
 		LcCreateNewBranchFromCommit:         "create new branch off of commit",
-		LcViewStashFiles:                    "view stash entry's files",
 		LcBuildingPatch:                     "building patch",
 		LcViewCommits:                       "view commits",
 		MinGitVersionError:                  "Git version must be at least 2.0 (i.e. from 2014 onwards). Please upgrade your git version. Alternatively raise an issue at https://github.com/jesseduffield/lazygit/issues for lazygit to be more backwards compatible.",
@@ -986,10 +1083,14 @@ func EnglishTranslationSet() TranslationSet {
 		NavigationTitle:                     "List Panel Navigation",
 		SuggestionsCheatsheetTitle:          "Suggestions",
 		SuggestionsTitle:                    "Suggestions (press %s to focus)",
-		ExtrasTitle:                         "Extras",
+		ExtrasTitle:                         "Command Log",
 		PushingTagStatus:                    "pushing tag",
 		PullRequestURLCopiedToClipboard:     "Pull request URL copied to clipboard",
+		CommitDiffCopiedToClipboard:         "Commit diff copied to clipboard",
+		CommitSHACopiedToClipboard:          "Commit SHA copied to clipboard",
+		CommitURLCopiedToClipboard:          "Commit URL copied to clipboard",
 		CommitMessageCopiedToClipboard:      "Commit message copied to clipboard",
+		CommitAuthorCopiedToClipboard:       "Commit author copied to clipboard",
 		LcCopiedToClipboard:                 "copied to clipboard",
 		ErrCannotEditDirectory:              "Cannot edit directory: you can only edit individual files",
 		ErrStageDirWithInlineMergeConflicts: "Cannot stage/unstage directory containing files with inline merge conflicts. Please fix up the merge conflicts first",
@@ -1028,10 +1129,16 @@ func EnglishTranslationSet() TranslationSet {
 		LcOpenCommitInBrowser:               "open commit in browser",
 		LcViewBisectOptions:                 "view bisect options",
 		ConfirmRevertCommit:                 "Are you sure you want to revert {{.selectedCommit}}?",
+		RewordInEditorTitle:                 "Reword in editor",
+		RewordInEditorPrompt:                "Are you sure you want to reword this commit in your editor?",
+		HardResetAutostashPrompt:            "Are you sure you want to hard reset to '%s'? An auto-stash will be performed if necessary.",
+		CheckoutPrompt:                      "Are you sure you want to checkout '%s'?",
+		UpstreamGone:                        "(upstream gone)",
+		NukeDescription:                     "If you want to make all the changes in the worktree go away, this is the way to do it. If there are dirty submodule changes this will stash those changes in the submodule(s).",
+		DiscardStagedChangesDescription:     "This will create a new stash entry containing only staged files and then drop it, so that the working tree is left with only unstaged changes",
 		Actions: Actions{
 			// TODO: combine this with the original keybinding descriptions (those are all in lowercase atm)
 			CheckoutCommit:                    "Checkout commit",
-			CheckoutReflogCommit:              "Checkout reflog commit",
 			CheckoutTag:                       "Checkout tag",
 			CheckoutBranch:                    "Checkout branch",
 			ForceCheckoutBranch:               "Force checkout branch",
@@ -1039,6 +1146,7 @@ func EnglishTranslationSet() TranslationSet {
 			Merge:                             "Merge",
 			RebaseBranch:                      "Rebase branch",
 			RenameBranch:                      "Rename branch",
+			SetUnsetUpstream:                  "Set/unset upstream",
 			CreateBranch:                      "Create branch",
 			CherryPick:                        "(Cherry-pick) Paste commits",
 			CheckoutFile:                      "Checkout file",
@@ -1049,12 +1157,19 @@ func EnglishTranslationSet() TranslationSet {
 			DropCommit:                        "Drop commit",
 			EditCommit:                        "Edit commit",
 			AmendCommit:                       "Amend commit",
+			ResetCommitAuthor:                 "Reset commit author",
+			SetCommitAuthor:                   "Set commit author",
 			RevertCommit:                      "Revert commit",
 			CreateFixupCommit:                 "Create fixup commit",
 			SquashAllAboveFixupCommits:        "Squash all above fixup commits",
 			CreateLightweightTag:              "Create lightweight tag",
 			CreateAnnotatedTag:                "Create annotated tag",
 			CopyCommitMessageToClipboard:      "Copy commit message to clipboard",
+			CopyCommitDiffToClipboard:         "Copy commit diff to clipboard",
+			CopyCommitSHAToClipboard:          "Copy commit SHA to clipboard",
+			CopyCommitURLToClipboard:          "Copy commit URL to clipboard",
+			CopyCommitAuthorToClipboard:       "Copy commit author to clipboard",
+			CopyCommitAttributeToClipboard:    "Copy to clipboard",
 			MoveCommitUp:                      "Move commit up",
 			MoveCommitDown:                    "Move commit down",
 			CustomCommand:                     "Custom command",
@@ -1067,14 +1182,21 @@ func EnglishTranslationSet() TranslationSet {
 			UnstageFile:                       "Unstage file",
 			UnstageAllFiles:                   "Unstage all files",
 			StageAllFiles:                     "Stage all files",
-			IgnoreFile:                        "Ignore file",
+			IgnoreExcludeFile:                 "Ignore or Exclude file",
+			IgnoreFile:                        "Ignore or Exclude file",
+			IgnoreFileErr:                     "Cannot ignore .gitignore",
+			ExcludeFile:                       "Exclude file",
+			ExcludeFileErr:                    "Cannot exclude .git/info/exclude",
+			ExcludeGitIgnoreErr:               "Cannot exclude .gitignore",
 			Commit:                            "Commit",
 			EditFile:                          "Edit file",
 			Push:                              "Push",
 			Pull:                              "Pull",
 			OpenFile:                          "Open file",
 			StashAllChanges:                   "Stash all changes",
+			StashAllChangesKeepIndex:          "Stash all changes and keep index",
 			StashStagedChanges:                "Stash staged changes",
+			StashUnstagedChanges:              "Stash unstaged changes",
 			GitFlowFinish:                     "Git flow finish",
 			GitFlowStart:                      "Git Flow start",
 			CopyToClipboard:                   "Copy to clipboard",
@@ -1097,7 +1219,6 @@ func EnglishTranslationSet() TranslationSet {
 			InitialiseSubmodule:               "Initialise submodule",
 			BulkInitialiseSubmodules:          "Bulk initialise submodules",
 			BulkUpdateSubmodules:              "Bulk update submodules",
-			BulkStashAndResetSubmodules:       "Bulk stash and reset submodules",
 			BulkDeinitialiseSubmodules:        "Bulk deinitialise submodules",
 			UpdateSubmodule:                   "Update submodule",
 			DeleteTag:                         "Delete tag",
@@ -1105,6 +1226,7 @@ func EnglishTranslationSet() TranslationSet {
 			NukeWorkingTree:                   "Nuke working tree",
 			DiscardUnstagedFileChanges:        "Discard unstaged file changes",
 			RemoveUntrackedFiles:              "Remove untracked files",
+			RemoveStagedFiles:                 "Remove staged files",
 			SoftReset:                         "Soft reset",
 			MixedReset:                        "Mixed reset",
 			HardReset:                         "Hard reset",
