@@ -17,6 +17,7 @@ func polishTranslationSet() TranslationSet {
 		PassUnameWrong:                      "Niewłaściwe hasło, fraza lub nazwa użytkownika",
 		CommitChanges:                       "Zatwierdź zmiany",
 		AmendLastCommit:                     "Zmień ostatni commit",
+		AmendLastCommitTitle:                "Zmień Ostatni Commit",
 		SureToAmend:                         "Czy na pewno chcesz zmienić ostatni commit? Możesz zmienić komunikat commitu z panelu commitów.",
 		NoCommitToAmend:                     "Brak commitów do zmiany.",
 		CommitChangesWithEditor:             "Zatwierdź zmiany używając edytora",
@@ -29,7 +30,6 @@ func polishTranslationSet() TranslationSet {
 		LcToggleStagedAll:                   "przełącz stan poczekalni wszystkich",
 		LcRefresh:                           "odśwież",
 		LcScroll:                            "przewiń",
-		LcCommitFileFilter:                  "Filtrowanie commitów",
 		FilterStagedFiles:                   "Pokaż tylko pliki w poczekalni",
 		FilterUnstagedFiles:                 "Pokaż tylko pliki poza poczekalnią",
 		ResetCommitFilterState:              "Resetuj filtr commitów",
@@ -61,7 +61,6 @@ func polishTranslationSet() TranslationSet {
 		CloseConfirm:                        "{{.keyBindClose}}: zamknij, {{.keyBindConfirm}}: potwierdź",
 		LcClose:                             "zamknij",
 		LcSquashDown:                        "ściśnij",
-		LcResetToThisCommit:                 "zresetuj do tego commita",
 		LcFixupCommit:                       "napraw commit",
 		NoCommitsThisBranch:                 "Brak commitów dla tej gałęzi",
 		OnlySquashTopmostCommit:             "Można tylko spłaszczyć najwyższy commit",
@@ -84,7 +83,6 @@ func polishTranslationSet() TranslationSet {
 		SureDropStashEntry:                  "Jesteś pewny, że chcesz porzucić tę pozycję w schowku?",
 		NoTrackedStagedFilesStash:           "Nie masz śledzonych/zatwierdzonych plików do przechowania",
 		StashChanges:                        "Przechowaj zmiany",
-		MergeAborted:                        "Scalanie anulowane",
 		OpenConfig:                          "otwórz konfigurację",
 		EditConfig:                          "edytuj konfigurację",
 		ForcePush:                           "Wymuś wysłanie",
@@ -176,7 +174,7 @@ func polishTranslationSet() TranslationSet {
 		AmendingStatus:                      "poprawianie",
 		CherryPickingStatus:                 "przebieranie",
 		CommitFiles:                         "Pliki commita",
-		LcViewCommitFiles:                   "przeglądaj pliki commita",
+		LcViewItemFiles:                     "przeglądaj pliki commita",
 		CommitFilesTitle:                    "Pliki commita",
 		LcCheckoutCommitFile:                "plik wybierania",
 		LcDiscardOldFileChange:              "porzuć zmiany commita dla tego pliku",
@@ -210,7 +208,7 @@ func polishTranslationSet() TranslationSet {
 		PressEnterToReturn:                  "Wciśnij enter żeby wrócić do lazygit",
 		LcViewStashOptions:                  "wyświetl opcje schowka",
 		LcStashAllChanges:                   "przechowaj zmiany",
-		LcStashStagedChanges:                "przechowaj zmiany z poczekalni",
+		LcStashAllChangesKeepIndex:          "przechowaj zmiany z poczekalni",
 		LcStashOptions:                      "Opcje schowka",
 		NotARepository:                      "Błąd: nie jesteś w repozytorium",
 		LcJump:                              "przeskocz do panelu",
