@@ -39,6 +39,8 @@ var (
 	OptionsFgColor = style.New()
 
 	DiffTerminalColor = style.FgMagenta
+
+	UnstagedChangesColor = style.New()
 )
 
 // UpdateTheme updates all theme variables
@@ -52,6 +54,9 @@ func UpdateTheme(themeConfig config.ThemeConfig) {
 	cherryPickedCommitFgTextStyle := GetTextStyle(themeConfig.CherryPickedCommitFgColor, false)
 	CherryPickedCommitTextStyle = cherryPickedCommitBgTextStyle.MergeStyle(cherryPickedCommitFgTextStyle)
 
+	unstagedChangesTextStyle := GetTextStyle(themeConfig.UnstagedChangesColor, false)
+	UnstagedChangesColor = unstagedChangesTextStyle
+
 	GocuiSelectedLineBgColor = GetGocuiStyle(themeConfig.SelectedLineBgColor)
 	OptionsColor = GetGocuiStyle(themeConfig.OptionsTextColor)
 	OptionsFgColor = GetTextStyle(themeConfig.OptionsTextColor, false)
