@@ -19,9 +19,9 @@ git add .
 git commit -am "myfile2"
 
 cd ..
-git clone --bare ./actual actual_remote
+git clone --bare ./repo origin
 
-cd actual
+cd repo
 
 echo test3 > myfile3
 git add .
@@ -30,6 +30,6 @@ echo test4 > myfile4
 git add .
 git commit -am "myfile4"
 
-git remote add origin ../actual_remote
+git remote add origin ../origin
 git fetch origin
 git config push.default nothing
