@@ -11,7 +11,7 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-// see https://github.com/jesseduffield/lazygit/blob/master/docs/Integration_Tests.md
+// see docs/Integration_Tests.md
 // This file can be invoked directly, but you might find it easier to go through
 // test/lazyintegration/main.go, which provides a convenient gui wrapper to integration tests.
 //
@@ -38,7 +38,7 @@ func main() {
 		},
 		mode,
 		speedEnv,
-		func(_t *testing.T, expected string, actual string, prefix string) {
+		func(_t *testing.T, expected string, actual string, prefix string) { //nolint:thelper
 			assert.Equal(MockTestingT{}, expected, actual, fmt.Sprintf("Unexpected %s. Expected:\n%s\nActual:\n%s\n", prefix, expected, actual))
 		},
 		includeSkipped,
